c=======================================================================
c***********************************************************************
      subroutine gpp_cal(ngt)
c***********************************************************************
c=======================================================================

c=======================================================================
c
c     this routine calculates the co2 net assimilation by leaves
c
c     output: xgpp  : leaf gross primary productivity (gC m-2 d-1 for
c                     an leaf layer).
c
c=======================================================================
      implicit none
      
      include './com_18/parameter.common'
      include './com_18/acclim.common'
      include './com_18/climin0.common'
      include './com_18/climin.common'
      include './com_18/coord.common'
      include './com_18/cstpi.common'
      include './com_18/c3cst.common'
      include './com_18/c3en.common'
      include './com_18/c4cst.common'
      include './com_18/cte.common'
      include './com_18/day_corr.common'
      include './com_18/deltac13.common'
      include './com_18/down_reg.common'
      include './com_18/eco.common'
      include './com_18/ecoin.common'
      include './com_18/envi.common'
      include './com_18/ext_con.common'
      include './com_18/ext_con2.common'
      include './com_18/gcaci2.common'
      include './com_18/h2ocst.common'
      include './com_18/lai.common'
      include './com_18/laih2o.common'
      include './com_18/laiste.common'
      include './com_18/loop.common'
      include './com_18/monthcst.common'
      include './com_18/nspc.common'
      include './com_18/pho_sch.common'
      include './com_18/pnpp2.common'
      include './com_18/monwat.common'
      include './com_18/rblcst1.common'
      include './com_18/res_par.common'
      include './com_18/res_temp2.common'
      include './com_18/snow.common'
      include './com_18/temper.common'
      include './com_18/tresh.common'
      include './com_18/varday.common'

c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt


      integer ipool,ih,irad
      
      real*4 a0,a1,b,b1,b2,beta0
      real*4 c,c1,c2,co2cl,coeffs
      real*4 d,f00,fac,fac0,fac1,fac2,fac02,fac04,fac05
      real*4 fac23,fac3,fac4,fac5,fac6,fac7,fac8,fac34,fac35
      real*4 facgj,facgjm,factt,factt2,farbl,fard,fkt0,fkt3
      real*4 fkt4,fkt5,fracth,fs,fh2o_mth,g1new
      real*4 gamet,gj,gjm0,gjmax,gkc,gko
      real*4 gn,gn0,gn1,gn2,gn3,gnd,gst
      real*4 pkc,pko,q,r,rd,rd0,rd34
      real*4 rbl04,rbl05,rd35,rdfac,rho1,rho2,roo,rtot
      real*4 rto,s,sqrtq,tdep,test,test1,test2,tfact
      real*4 tfacto,theta0,unitchg,vcm00,vcmax,vt0,wat_eff
      real*4 xkt,xkt0,rtot_w,test0
      
c-----------------------------------------------
    
      dimension gn2(3),gnd(3),g1new(ndy,nplant),fh2o_mth(nm)
      real*4 co2past,xco2,x365,x567,rfac_CO2,rvcm,rjm,rrd
      real*4 tempast,rdaccl,tempast_m,rdaccl_f
      integer iy_past,maxyr,m,m_past,maxmth,k

      character*100 formatw,formaty



c=======================================================================
c     initialisation
c=======================================================================

      do ipool = 1, npool
        resp_fac(ip,ipool,iday) = 0.
      enddo

      gca(ip,iday) = 0.
      gci(ip,iday) = 0.
c-----------------------------------------------------------------------
      zgpp(ip,iday)   = 0.
CNPP            znpp(ip,iday)   = 0.
      zfract(ip,iday) = 0.
      zfh2o(ip,iday)  = 0.
c-----------------------------------------------------------------------

c======================================================================		
c      downregulation of vcmax and jmax (FACE data)
c        rvcm = downregulation factor for Vcmax
c        rjm = downregulation factor for Jmax 
c        rrd = downregulation factor for Rd
c        CO2 is averaged over the last N years (N=maxyr, 
c                                                with maxyr+1<20) 
c======================================================================

      if (jdwnCO2.ge.1) then
        co2past = 0.
        maxyr = 4
        do iy_past = 2, maxyr+1
         co2past = co2past + co2_prev(iy_past)/float(maxyr)
        end do 
        xco2 = co2past/(co2past+gkc3)
        x365 = 365./(365.+gkc3)
        x567 = 567./(567.+gkc3)
        rfac_CO2 = (xco2-x365)/(x567-x365)  
        rvcm = 1. + (rvcm567(ip)-1.)*rfac_CO2
        if (rvcm.le.0.1) rvcm = 0.1
        rjm = 1. + (rjm567(ip)-1.)*rfac_CO2
        if (rjm.le.0.1) rjm = 0.1
        if (jdwnCO2.eq.1) then
         rrd = rvcm
        else
         rrd = 1.
        endif   
      else
        rvcm = 1.
        rjm = 1.
        rrd = 1.
      endif

c======================================================================		
c      acclimation of leaf respiration to temperature
c        jrd_accl = 0/1/2 
c         0 : No acclimation
c         1 : long-term (several years) acclimation for all plant parts 
c         2 : mid-term (several months) acclimation for leaves
c             and long-term (several years) acclimation for structural
c             parts
c        
c        rdsurvc = Rd/Vcmax = assumed to respond to temperature of the 
c                  previous years - decreases at higher temperatures
c        tempast = mean temperature of the N previous years (N=maxyr, 
c                               with maxyr+1.le.5) (long-term)
c        tempast_m = mean temperature of the N previous months 
c                     (N=maxmth, with maxmth<12)   (mid-term)
c        rdaccl = temperature acclimation factor for structural parts
c        rdaccl_f = temperature acclimation factor for leaves        
c======================================================================		

      if (jrd_accl.eq.0) then
        rdaccl = 1.
	rdaccl_f = 1.
        rdsurvc = rdsurvc0
      else      
        tempast = 0.
        maxyr = 4
        do iy_past = 2, maxyr+1
         tempast = tempast + ytem_prev(ngt,iy_past)/float(maxyr)
        end do
c  adapted from Wythers et al., GCB, 11, 435-449, 2005
c      rdaccl = normalized ratio = (0.14 - 0.002*tcel)/0.09
c            with 0.09 the value of the bracket term at 25°C 	 
        rdaccl=1.5556-0.0222*tempast
	rdsurvc = rdsurvc0 
        if (jrd_accl.eq.1) then
	  rdaccl_f = rdaccl
	else 
	  m = imonth(iday)
	  tempast_m = 0.
	  maxmth = 2
	  do k = 1, maxmth
	   m_past = m-k
	   if (m_past.le.0) then
	    tempast_m = tempast_m+py_mtem(ngt,m_past+nm)/float(maxmth)
	   else
	    tempast_m = tempast_m+tcel0(m_past)/float(maxmth)
	   endif
	  end do 
	  rdaccl_f = 1.5556-0.0222*tempast_m
        endif
      endif   
  

c=======================================================================
c la resistance stomatique (pas g0 mais g1) a ete multipliee par 
c l'exponentielle de Wijk plottee sur Leuning

      wat_eff = (water(iday)-0.5*wattresh2(ip)) / (1.-0.5*wattresh2(ip))
      if (wat_eff.lt.0.) wat_eff=0.
      fs = 1.-0.016572*exp(4.1*(1.-wat_eff))

      g1new(iday,ip) = g1(ip) * fs

c=======================================================================
c   beginning of the calculation:
c   g0     = intercept for the stomatal conductance;
c   g1     = slope for the stomatal conductance;
c   temp  = temperature in k;
c   gjmax = light potential rate of electron tranport on area basis
c           (mueq m-2 s-1);
c   gj    = potential rate of electron transport on area basis
c           (mueq m-2 s-1);
c   apar   = solar irradiance (micromol photons/(m2 s));
c   ea    = activation energy used to calculate the temperature
c           dependance of a paramater(j mlo-1);
c   gkc   = michaelis constant for co2 (mubar);
c   gko   = michaelis constant for o2 (mbar);
c   pkc   = turnover number of rup2 carboxylase (s-1);
c   pko   = turnover number of rup2 oxygenase (s-1);
c   vcmax = maximum carboxylation velocity (mumol m-2 s-1);
c   gamet = co2 compensation point without dark respiration (mubar);
c   rd   = dark respiration (mumol m-2 s-1);
c   co2a = atmospheric partial pressure of co2 (mubar);
c   hs     = air relative humidity;
c   o2cl   = partial pressure of o2;
c   rbl    = boundary layer resistance (mol m-2 s-1).
c=======================================================================

c=======================================================================
c   C4 parameters:
c 
c   vc4     = rubisco capacity (mumol m-2 s-1);
c   xkt    = initial slope of the photosynthetic co2 response 
c            (mol m-2 s-1).
c=======================================================================

c=======================================================================
c   loops over the hours
c=======================================================================

        do ih = 1, nh2
c no photosynthesis below -10 oC    (-4 oC in earlier version)  
          if(temp(iday,ih).ge.(temp0-10.)) then

c=======================================================================
c   C3 plants
c=======================================================================

            tdep  = (temp(iday,ih) - 298.15) / temp(iday,ih)
            tfact = exp(tdep * eapkc)
            gkc   = gkc3   * exp(tdep * eagkc)
            gko   = gko3   * exp(tdep * eagko)
            pkc   = pkc3   * tfact
            pko   = pkcko  * pkc
            gamet = gkc * o2cl * pko / (2 * gko * pkc)
            f00   = co2a - gamet
            test1 = f00 / (co2a + 2. * gamet)
            fac1  = gkc * (1. + o2cl/gko)
            facgj = 1. + exp((sjm*temp(iday,ih)-hjm)/temp(iday,ih))
            tfacto = tfact 

c=======================================================================
c    C4 plants
c=======================================================================

            fac   = (temp(iday,ih) - 298.15) / 10. 
            factt  = 0.3 * temp(iday,ih)
            factt2 = 1.3 * temp(iday,ih)
            xkt0  = (q10**fac)
            vt0   = xkt0 
     &            / ((1+exp(fact0-factt)) * (1+exp(factt-fact1)))
            rdfac = factt2-fact2
            if(rdfac.lt.-40.) rdfac = -40.
            rd0   = xkt0 / (1. + exp(rdfac))

                if (ic4(ip).eq.1) then
                  resp_fac(ip,1,iday) = resp_fac(ip,1,iday) 
     &                   + rd0 *rrd*rdaccl_f* (1. - snow_frac(iday))
                else
                  resp_fac(ip,1,iday) = resp_fac(ip,1,iday) 
     &                   + rrd*rdaccl_f*tfacto*(1. - snow_frac(iday))
                endif
                resp_fac(ip,2,iday) = resp_fac(ip,2,iday) 
     &                   + rrd*rdaccl*tfacto*(1. - snow_frac(iday))

                a1     = 1.6 / g0(ip) + rbl(ip,iday)
                fac0   = g1new(iday,ip) * hs(iday,ih) / co2a

                gn  = 0.
                gn0 = 0.
                gn1 = 0.
                gn3 = 0.

c======================================================================		
		
                vcm00  = vcm0(ip)*rvcm

                if (ic4(ip).eq.1) then

                  rd  = rd0 * rdsurvc * vcm0(ip)*rrd*rdaccl_f 
                  xkt = xkt0 * xkc4
                  fkt0 = 1.6 * xkt
                  fkt3 = 1. + xkt * rbl(ip,iday)
                  fkt5 = xkt * a1
                  a0   = -fac0 * fkt3

                  test0 = xkt * co2a
c   test 1
c-----------------------------------------------------------------------
                  if(test0.gt.rd.and.a0.gt.0.) then
                    fac2  = g0(ip) - fac0 * rd
                    fac4  = co2a + rd * rbl(ip,iday)
                    fkt4 = xkt * fac4
                    b     = 0.5*( fkt4*fac0 - fac2*fkt3 - fkt0 )
                    c     =       fkt4*fac2 + fkt0*rd
                    roo   = b*b - a0*c
                    gn3 = -(b + sqrt(roo))/a0
                  else

c=======================================================================
c     limits the stomatal conductance to g0
c=======================================================================

                    gn3 = (xkt*co2a + rd*fkt5) / (1.+fkt5)
                  endif

                  gn1 = vcm00 * vt0 /2.

                else

                  vcmax  = vcm00 * tfacto
                  rd     = rdsurvc * vcm0(ip) * rrd*rdaccl_f * tfacto
                  a0     = rbl(ip,iday) * fac0
                  test0  = vcmax*f00 
     &                   / (co2a + gkc*(1.+o2cl/gko))
                  fac3 = -fac0 * rd + g0(ip)
                  fac4 = f00 + rd * rbl(ip,iday)
                  fac5 = fac4 + 3. * gamet
                  fac6 = co2a + rd * a1
                  fac7 = fac6 - gamet
                  fac8 = fac6 + 2. * gamet
                  fard = 1.6 * rd
                  farbl = 1.6 + rbl(ip,iday) * fac3
                  fac04 = fac0 * fac4
                  fac05 = fac0 * fac5
                  fac34 = fac3 * fac4
                  fac35 = fac3 * fac5
                  rbl04 = farbl - fac04
                  rbl05 = farbl - fac05
                  rd34  = fard + fac34
                  rd35  = fard + fac35

c=======================================================================
c   rubisco limitation
c=======================================================================

c   test2
c-----------------------------------------------------------------------

                  if(test0.gt.rd.and.a0.gt.0.) then

                    fac2 = co2a + fac1+ rd * rbl(ip,iday)
                    fac02 = fac0 * fac2
                    fac23 = fac2 * fac3

                    b  = ( (farbl - fac02)/a0 - vcmax )/3.
                    c  = - (vcmax*rbl04 + fac23 + fard)/a0
                    d  =   (vcmax*rd34)/a0

                    b2 = b*b
                    q  = b2 - c/3.
                    r  = b*(b2 - 0.5*c) + 0.5*d
                    sqrtq = sqrt(q)
                    coeffs = r /(sqrtq*q)

                    if(coeffs .lt. -1.) coeffs = -1.
                    if (coeffs.gt.1.) coeffs = 1.

                    s   = acos(coeffs)
                    gn1 = -2.*sqrtq*cos((4.*pi+s)/3.) - b 

                  else

c=======================================================================
c   limits the stomatal conductance to g0
c=======================================================================

                    b     = -0.5*(fac6 + vcmax*a1 + fac1)
                    c     =              vcmax*fac7
                    roo   = b*b - a1*c
                    gn1 = -(b + sqrt(roo))/a1

                  endif

                  gn3   = vcmax / 2.
c                  gjm0   = 1.67 * vcm0(ip) * rjm
                  gjm0   = 2.11 * vcm0(ip) * rjm 
                  gjmax  = gjm0 * exp(tdep * ejm) / facgj 
 
                endif

c=======================================================================
c   loops over the lai
c
c   an   = potential c3 net assimilation rate (micromol m-2 s-1);
c   gn   = potential c3 gross assimilation rate (micromol m-2 s-1).
c 
c   then;
c   sums the  values --> daily values for each lai step.
c=======================================================================

                  gn  = 0.
                  do irad = 1, 3
                    gn2(irad) = 0.
                  enddo
                  if (ic4(ip).eq.1) then 

c=======================================================================
c   irradiance limitation
c=======================================================================

                    do irad = 1, 3
                      gn2(irad) = alpc4 * apar(ip,iday,ih,irad) 
                    enddo

                  else

                    do irad = 1, 3

                      if(apar(ip,iday,ih,irad).gt.0.) then
                        facgjm = 2.1*gjmax + apar(ip,iday,ih,irad)
                        gj  = gjmax * apar(ip,iday,ih,irad)/facgjm
                        gj  = gj / 4.   
                        test2 = test1 * gj
c   test 3
c-----------------------------------------------------------------------
                        if(test2.gt.rd.and.a0.gt.0.) then

                          b = ( - gj       + rbl05/a0 )/3.
                          c =   -(gj*rbl04 + rd35)/a0
                          d =    (gj*rd34        )/a0

                          b2 = b*b
                          q  = b2 - c/3.
                          r  = b*(b2 - 0.5*c) + 0.5*d
                          sqrtq = sqrt(q)
                          coeffs = r /(sqrtq*q)
                          if(coeffs .lt. -1.) coeffs = -1.
                          if (coeffs.gt.1.) coeffs = 1.
                          s      = acos(coeffs)
                          gn2(irad) = -2.*sqrtq*cos((s+4.*pi)/3.) - b
 
                        else

c=======================================================================
c   limits the stomatal conductance to g0
c=======================================================================

                          b     = -0.5*(fac8 + gj*a1)
                          c     =              gj*fac7
                          roo   = b*b - a1*c
                          gn2(irad) = -(b + sqrt(roo))/a1

                        endif
                      endif
                    enddo
                  endif

                  if(gn1  .lt. 0.) gn1  = 0.
                  do irad = 1, 3
                    if(gn2(irad) .lt. 0.) gn2(irad) = 0.
                  enddo

                  if(gn3  .lt. 0.) gn3  = 0.

c=======================================================================
c   coupling of limitations
c=======================================================================

                  theta0 = 0.90
                  beta0  = 0.90

                  do irad = 1, 3
                    b1 = - 0.5*(gn1 + gn2(irad))
                    c1 = gn1 * gn2(irad)
                    rho1 = b1*b1 - theta0*c1
                    gn0 = -(b1 + sqrt(rho1))/theta0

                    b2 = - 0.5*(gn0 + gn3)
                    c2 = gn0 * gn3
                    rho2 = b2*b2 - beta0*c2
                    gnd(irad) = -(b2 + sqrt(rho2))/beta0

                    if(gnd(irad) .lt. 0.)  gnd(irad) = 0.
                  enddo

                  gn = sunhour(iday) * (fsun(ip,iday,ih) * gnd(1) 
     &               + (1.-fsun(ip,iday,ih)) * gnd(2))
     &               + (1. - sunhour(iday)) * gnd(3)
                  gn = gn * corr_hour(iday,ih)
                  zgpp(ip,iday) = zgpp(ip,iday)  + gn

CNPP                  znpp(ip,iday) = znpp(ip,iday) 
CNPP     &                               + gn - rd
c modification Wijk : g1new au lieu g1
                  gst = g0(ip) + g1new(iday,ip)*(gn-rd)*hs(iday,ih)/
     &                                                     co2a
                  if(gst.le.g0(ip)) gst = g0(ip)
                  rtot = 1.6/gst + rbl(ip,iday)
                  unitchg = unitfac * (1.+(tcel(iday)/temp0)) 
     &                              * patm0/patm
c rtot_w: total resistance for water vapour (s m-1) (stom+bl+aer)
c-----------------------------------------------------------------------
                  rtot_w = 1./(gst*unitchg)
     &                   + rbw(ip,iday) + rae(ip,iday)
                  co2cl = co2a - (gn-rd)*rtot
                  if(co2cl.le.0.) co2cl = 0. 

                  gca(ip,iday) = gca(ip,iday) + co2a / rtot
                  gci(ip,iday) = gci(ip,iday) + co2cl /rtot

                  fracth = delc1 + delc2(ip) * co2cl / co2a

                  zfract(ip,iday) = zfract(ip,iday)
     &                                 + fracth * gn
                  zfh2o(ip,iday) = zfh2o(ip,iday)
     &              + qsatmb(iday,ih)*100.*(1.-hs(iday,ih))
     &              / (rtot_w*rgas_v*temp(iday,ih))

          endif
        enddo

c=======================================================================
c   transformation into g m-2 day-1 for one lai layer
c=======================================================================


      zgpp(ip,iday) = zgpp(ip,iday) * transfo * (1. - snow_frac(iday))
CNPP              znpp(ip,iday) = znpp(ip,iday) * transfo
CNPP     &                           * (1. - snow_frac(iday))
      zfract(ip,iday) = zfract(ip,iday)*transfo * (1. - snow_frac(iday))
      zfh2o(ip,iday) = zfh2o(ip,iday) * transfw * (1. - snow_frac(iday))

      gca(ip,iday) = gca(ip,iday) * transfo * (1. - snow_frac(iday))
      gci(ip,iday) = gci(ip,iday) * transfo * (1. - snow_frac(iday))
      
      
c      do ipool = 1, npool
c        resp_fac_temp(ip,ipool,iday,ngt) 
c     &                       = resp_fac(ip,ipool,iday) 
c      enddo

c      gca_temp(ip,iday,ngt) = gca(ip,iday)
c      gci_temp(ip,iday,ngt) = gci(ip,iday)

c      zgpp_temp(ip,iday,ngt) = zgpp(ip,iday)  

c      zfract_temp(ip,iday,ngt) = zfract(ip,iday)
c      zfh2o_temp(ip,iday,ngt) = zfh2o(ip,iday)         

      return 
      end subroutine gpp_cal