c=======================================================================
c**********************************************************************
      subroutine soil_resp(ngt)
c***********************************************************************
c=======================================================================
      implicit none
c=======================================================================
c   This routine estimates the monthly soil respiration rate
c=======================================================================

      include './com_18/parameter.common'
      include './com_18/annee.common'
      include './com_18/annppf.common'
      include './com_18/biomasse.common'
      include './com_18/burned.common'      
      include './com_18/climin.common'
      include './com_18/cte.common'
      include './com_18/dayres.common'
      include './com_18/eco.common'
      include './com_18/ecoin.common'
      include './com_18/fire_emi.common'
      include './com_18/firevpar.common'      
      include './com_18/gama.common'
      include './com_18/griddata.common'
      include './com_18/landuse.common'      
      include './com_18/litiere.common'
      include './com_18/loop.common'
      include './com_18/mort.common'
      include './com_18/nspc.common'
      include './com_18/textcst1.common'
      include './com_18/soil_marie.common'
      include './com_18/soil_pool.common'
      include './com_18/smrd.common'
      include './com_18/sresp.common'
      include './com_18/varday.common'

      
c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt
      
      integer iday2,iyear,kpool,max_year
      
      real*4 b,cm,cmopt,cmoxm1,fin,fout,fsw,psat,rg,rt,tem10,
     &       test_conv,test_conv_max,testc,xlit_prod_tot,xm1  
     
c-----------------------------------------------   
      dimension xmresp(3,ndy),Fin_lit(2,ndy)
      real*4 xmresp,Fin_lit,phi_D_mean,sum_mean,totfrac


c=======================================================================
c   soil respiration factor calculation i.e. 
c               soil respiration
c              ------------------
c              soil carbon content
c=======================================================================

      xm1   = (xm1cla*cla   + xm1sil*sil   + xm1san*san)*0.01
      cmopt = (cmoptcla*cla + cmoptsil*sil + cmoptsan*san)*0.01
      psat  = (psatcla*cla  + psatsil*sil  + psatsan*san)*0.01  
      cmoxm1 = cmopt**xm1

      do iday = 1, nd

        xdnep(iday) = xdnpp(iday)

        tem10 = (tcel(iday) - 10.) / 10.

        cm  = ((fci-wpi)*water(iday) + wpi)/fsi
        b   = (cm**xm1-cmoxm1)/(1.-cmoxm1)
        fsw = 0.2 + 0.8 * psat**(b*b)
        rg  = facgrnd * (q10grnd**tem10)*fsw
        rt  = factree * (q10tree**tem10)*fsw

         xmresp(1,iday) = rg
         xmresp(2,iday) = rt
         xmresp(3,iday) = rt
      enddo

c=======================================================================
c   soil carbon estimation
c=======================================================================

      max_year = 1
      if(nys.eq.1) max_year = 1000
      test_conv_max = 0.001


       phi_D_mean  = 0.
       sum_mean = 0.

       do iday = 1, nd

        do kpool = 1, 2
          Fin_lit(kpool,iday) = 0.
         
        end do
	
	do ip = 1, npft
	  xlit_prod_tot=xlit_prod(ip,1,iday)+xlit_prod(ip,2,iday)
	  if (ip.le.npft0) phi_D_mean = phi_D_mean  
     &        + phi_D(ip) * xlit_prod_tot * frac(ip)
     	  sum_mean = sum_mean + xlit_prod_tot * frac(ip)

          Fin_lit(1,iday) = Fin_lit(1,iday) 
     &                    + xlit_prod(ip,1,iday)*frac(ip)
ctt          if(ip.le.nherb .or. ip.gt.npft0) then
ctt             Fin_lit(1,iday) = Fin_lit(1,iday) 
ctt     &                       + xlit_prod(ip,2,iday)*frac(ip)
ctt          else
             Fin_lit(2,iday) = Fin_lit(2,iday) 
     &                       + xlit_prod(ip,2,iday)*frac(ip)
ctt          endif

        end do 

        do kpool = 1, 2
          if(Fin_lit(kpool,iday).lt.0.) Fin_lit(kpool,iday) = 0.
        end do
       end do
       
       if (sum_mean.gt.1.e-10) then
         phi_D_mean = phi_D_mean/sum_mean
       else
         phi_D_mean = 0.
	     totfrac = 0.
	     do ip = 1, npft0
	       totfrac = totfrac + frac(ip)
	       phi_D_mean = phi_D_mean + frac(ip)*phi_D(ip)
	     end do
	     if (totfrac.gt.1.e-10) then
	       phi_D_mean = phi_D_mean*frac_nat(ngt)/totfrac
	     else
	       phi_D_mean = 0.
	     endif
       endif
       
c=======================================================================
c   Litter
c=======================================================================


          do kpool = 1, 2
            test_conv = 999999.
            iyear     = 0

c=======================================================================
c   beginning of integration loop
c=======================================================================

 8000       continue

            testc = xlit(kpool,nd)
            do iday = 1, nd

              iday2 = iday - 1
              if(iday.eq.1) iday2 = nd

c=======================================================================
c   incoming and outgoing fluxes
c=======================================================================


              Fout = gama1(kpool)*xmresp(kpool,iday)*xlit(kpool,iday2)
	      emi_burn_lit(iday) = frac_burn(iday) * phi_D_mean
     &                            * xlit(kpool,iday2)

              xhum_prod(kpool,iday) = alpha * Fout

c=======================================================================
c    pool calculation
c=======================================================================

              xlit(kpool,iday) = xlit(kpool,iday2)
     &                         + Fin_lit(kpool,iday) - Fout 
     &                         - emi_burn_lit(iday)
              if(xlit(kpool,iday).lt.0.01) xlit(kpool,iday) = 0.

            enddo

c=======================================================================
c    convergence test
c=======================================================================

            iyear = iyear + 1
            if(nys.eq.1) then

              if(xlit(kpool,nd).le.test_conv_max) then
                testc = abs(testc-xlit(kpool,nd))
              else
                testc = 100.*abs(testc-xlit(kpool,nd))
     &                / xlit(kpool,nd)
              endif
            else
              testc = 0.
            endif
            test_conv = testc
            if(iyear.ge.max_year) test_conv = 0.

c=======================================================================
c     end of integration loop
c=======================================================================

            if(test_conv.gt.test_conv_max) goto 8000

          enddo

c=======================================================================
c   HUMUS
c=======================================================================
c=======================================================================
c   first estimate of the humus pool:
c   initialisation for a steady state.
c=======================================================================

          test_conv = 9999999.
          iyear     = 0

c=======================================================================
c   beginning of integration loop
c=======================================================================

 8100     continue

          testc = xhumus(nd)

          do iday = 1, nd

            iday2 = iday - 1
            if(iday.eq.1) iday2 = nd

c=======================================================================
c   incoming and outgoing fluxes
c=======================================================================

            Fin = 0.

            do kpool = 1, 2
              Fin = Fin + xhum_prod(kpool,iday)
            enddo

            if(Fin .lt. 0.) Fin = 0.

            Fout = gama2 * xmresp(3,iday) * xhumus(iday2)

c=======================================================================
c    pool calculation
c=======================================================================

            xhumus(iday) = xhumus(iday2) + Fin - Fout
            if(xhumus(iday).lt.0.01) xhumus(iday) = 0.

          enddo

c=======================================================================
c   convergence test
c=======================================================================

          iyear = iyear + 1
          if(nys.eq.1) then

            if(xhumus(nd).le.test_conv_max) then
              testc = abs(testc-xhumus(nd))
            else
              testc = 100.*abs(testc-xhumus(nd))
     &              / xhumus(nd)
            endif

          else
            testc = 0.
          endif
          test_conv = testc
          if(iyear.ge.max_year) test_conv = 0.

c=======================================================================
c   end of integration loop
c=======================================================================

          if(test_conv.gt.test_conv_max) goto 8100

c=======================================================================
c    total soil carbon content and nep
c=======================================================================

       do iday = 1, nd
         ysoilr(1) = ysoilr(1) + xlit(1,iday)
         ysoilr(2) = ysoilr(2) + xlit(2,iday)
         ysoilr(3) = ysoilr(3) + xhumus(iday)
         xdnep(iday) = xdnep(iday) 
     &               - gama1(1)*xlit(1,iday)*xmresp(1,iday)*(1.-alpha)
     &               - gama1(2)*xlit(2,iday)*xmresp(2,iday)*(1.-alpha)
     &               - gama2*xhumus(iday)*xmresp(3,iday)
       end do

       do kpool = 1, 3
         ysoilr(kpool) = ysoilr(kpool) / float(nd)
         ysoilr(0) = ysoilr(0) + ysoilr(kpool)
       end do

      return
      end subroutine soil_resp