c=======================================================================
c***********************************************************************
      subroutine solar_trees(ngt)
c***********************************************************************
c=======================================================================
      implicit none
      
      include './com_18/parameter.common'
      include './com_18/ecoin.common'
      include './com_18/ext_con.common'
      include './com_18/landuse.common'
      include './com_18/loop.common'
      include './com_18/nspc.common'
      include './com_18/radcst.common'
      include './com_18/sol_in.common'
      include './com_18/xvalues.common'

c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt
      
      integer ih,irad
      real*4 facgk,facpkdif,frac_free,frac_tree_tot,gk,pkdif
      

c-----------------------------------------------
c========================================================================
c     cover fractions:
c         frac_tree_tot = total fraction of the pixel covered by trees
c         frac_free     = fraction of the pixel free from trees
c========================================================================

      frac_tree_tot = 0.
      if(frac_nat(ngt).gt.0.) then
        do ip = nherb+nbush+1,npft0
          frac_tree_tot = frac_tree_tot + frac(ip)
        end do
      endif
      if(frac_tree_tot.gt.1.001*frac_nat(ngt)) then
        write(61,*) 'ERROR total cover of trees',ngt
     &              ,frac_tree_tot,frac_nat(ngt)
        stop
      endif

      frac_free = 1. - frac_tree_tot / frac_nat(ngt)
      if(frac_free.lt.0.) frac_free = 0.
      if(frac_free.gt.1.) frac_free = 1.

c========================================================================
c     initialisation of the solar fluxes for the understorey:
c        par1 (photosynthetically active radiation)
c              1 direct radiation
c              2 diffuse radiation on sunny days
c              3 diffuse radiation on cloudy days
c        fsun0 fraction of sunlit leaves
c========================================================================

      do iday = 1, nd
        do ih = 1,nh2
          fsun0(iday,ih) = 1. * frac_free
          do irad = 1, 3
            par1(iday,ih,irad) = par0(iday,ih,irad) * frac_free
          end do
        end do
      end do

c========================================================================
c     calculation of solar fluxes and sunlit fraction for understorey
c========================================================================

      if(frac_free .lt. 1.) then
        do iday = 1, nd
          do ih = 1, nh2
            gk = 0.
            if(xmucar(iday,ih) .ne. 0.)  gk  = clump_fac * 0.5 
     &                                       / xmucar(iday,ih)
            pkdif = 0.8 * facome

            do ip = nherb+nbush+1,npft0
              if(frac(ip).gt.1.e-7) then
  
                facgk = - gk * xlai(ip,iday)
                if(facgk .lt. -40.) facgk = -40.
  
                fsun0(iday,ih) = fsun0(iday,ih) 
     &                         + exp(facgk) * frac(ip) / frac_nat(ngt)
                facpkdif = -pkdif    * xlai(ip,iday)
                if(facpkdif .lt. -40.) facpkdif = -40.

                par1(iday,ih,1) = par1(iday,ih,1) 
     &               + par0(iday,ih,1)*(1.-ome)*exp(facgk)
     &               * frac(ip) / frac_nat(ngt)
                par1(iday,ih,2) = par1(iday,ih,2)
     &               + par0(iday,ih,2)*(1.-rhoc0)*exp(facpkdif)
     &               * frac(ip) / frac_nat(ngt)
                par1(iday,ih,3) = par1(iday,ih,3) 
     &               + par0(iday,ih,3)*(1.-rhoc0)*exp(facpkdif)
     &               * frac(ip) /frac_nat(ngt)
              endif
            end do
          end do
        enddo
      endif

      return
      end subroutine solar_trees