c=======================================================================
c***********************************************************************
      subroutine givedrv(stept,time,y,drv)
c***********************************************************************

c=======================================================================
c the system to be solved consists in "nequat" ordinary differential
c equations of the form
c      .
c      y(1)      = drv(1)
c      .
c      y(2)      = drv(2)
c                .
c                .
c                .
c      .
c      y(nequat) = drv(nequat)
c
c where drv(i) depends on y(1), y(2), ..., y(nequat), and on time.
c please give your vector "drv".
c for example :
c
c     --------------------------------------
c      ny0 : year number
c      dn  : day number
c     --------------------------------------
c      nr=1 : snow (H2O)
c      nr=2 : soil water (H2O)
c     --------------------------------------
c     --------------------------------------
c      y(nres)   : reservoirs (gC m-2) or (gN m-2) or mm H2O
c      drv(nres) : dy/dt (gC m-2 day-1) or (gN m-2 day-1)
c                            or mm H2O day-1
c     --------------------------------------
c      fin_w(nres)  : input flux of each reservoir (mm H2O day-1)
c      fout_w(nres) : output flux of each reservoir (mm H2O day-1)
c     --------------------------------------
c=======================================================================

c      implicit double precision (a-h,o-z)
      implicit none
      include './com_18/parameter.common'
      include './com_18/climin0.common'
      include './com_18/cloud.common'
      include './com_18/coord.common'
      include './com_18/cstpi.common'
      include './com_18/cte.common'
      include './com_18/drain.common'
      include './com_18/eco.common'
      include './com_18/ecoin.common'
      include './com_18/ecopro.common'
      include './com_18/envi.common'
      include './com_18/fgr.common'
      include './com_18/flux_w.common'
      include './com_18/nspc.common'
      include './com_18/radcst.common'
      include './com_18/smrd.common'
      include './com_18/solpar.common'
      include './com_18/temper.common'
      include './com_18/varnow.common'
      include './com_18/vegfr.common'
      include './com_18/waflux.common'
      include './com_18/frac_change.common'
      include './com_18/xlaic.common'
      include './com_18/landuse.common'

c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer imeth,ip,j,jbrac,jnum,k0w,k1w,k2w,kj,kw,nint,nitmax,nr
     &      ,num1,numc,numit,ny0
     
      real*8  airmw,albs,albsn,alnlw,alnsw,avh2o,bts,cpair,delta,dn,dr
     &      ,drv,eint,eintpl,ej,ej1,ej2,emia,emidry,emis,emisn,emiwet
     &      ,ermax,err,err1,err2,esnmax,esnow,esoil,esomax,fgr_crop
     &      ,fgr_herb,fgr_past,fgr_tree,fgr_wood,fh2o,firdown,fnet,fnmax
     &      ,fnsw,fntj,frcso,frctr,fsnow,fwood,gama,pcdew,pcrain,prod
     &      ,qfrac,qh2o,qx,ra,rair,ram,rapso,rblws,rblwv,rbw,rbwm,rhoair
     &      ,rnfac,smlmax,solnet,t0dr,tatm,tca,tcb,time,tm3,tmfac,tr,tsf
     &      ,tsf1,tsf2,tsurf,us,usm,usmulm,usmulv,uss,was,x,x0,xii,xk
     &      ,xle,xleadi,xlice,xlog2,xlsml,xlw,xnn,xr,xrblwm,y,z0,zzlogm
c
c-----------------------------------------------

      real*4 tc,ftc,psat
      real*4 stept
      real*4 tmax,tmin
      real*4 cond_max,exces_run
      real*4 plant_lai,plant_fgrn
      real*4 plant_wai,wai_fgrn
      real*4 frcini
      integer indicmax
 
      dimension y(nequat),drv(nequat),ej(0:nde+1)

      ny0 = int(time/float(nd)+0.000001)+1
      dn  = time - float(ny0-1) * float(nd)

         asw = (y(2)-wpi)/(fci-wpi)

c   relative water amount with respect to saturation 
c   (used in emissivity and drainage calculations)
c-----------------------------------------------------------------------
         was = (y(2)-wpi)/(fsi-wpi)
         if(was .lt. 0.) was = 0.
         if(was .gt. 1.) was = 1.

c=======================================================================
c      hydrological model
c=======================================================================

c   bts: beta_Ts (Mintz and Walker, p. 1326)
c-----------------------------------------------------------------------
c        bts = 1. - dexp(-6.8*asw)
         bts = asw
         if(bts.lt.0.)bts=0.
         if(bts.gt.1.)bts=1.

c   diurnal tmin and tmax 
c-----------------------------------------------------------------------
         if(idayt .eq. 1) then
            tmax =  temi + 0.5 * delti
            tmin =  temi - 0.5 * delti
         elseif(idayt .eq. 2) then
            tmax =  temi
            tmin =  temi
         endif

c   tk : surface air temperature in Kelvin   
c-----------------------------------------------------------------------
         tk=temi+temp0

c   snd   : snow depth in mm 
c-----------------------------------------------------------------------
         snd = 10. * y(1)
         if(snd.lt.0.)snd=0.

c   fsnow : snow cover
c-----------------------------------------------------------------------
         fsnow = sqrt(0.01*snd)
         if(fsnow.gt.1.)fsnow=1.

c   fgreen: green cover  
c-----------------------------------------------------------------------
c         tlai = 0.
c         fgreen = 0.

         do ip =1,npft
c            dlai = plai(ip) / 5000.
c            prob=dexp(5000.*dlog(1.-dlai))
c            fgrn(ip) = (1.-prob)
            plant_lai = plai(ip)
            call fgrn_calc(plant_lai,plant_fgrn)
            fgrn(ip) = plant_fgrn 
            
c            fgreen = fgreen+frc(ip)*fgrn(ip)
         enddo
c         tlai = 5000.*(1.-dexp( (dlog(1.-fgreen))/5000. ))

c Wood Area Index for albedo of forest only
c only used in the total pixel albedo calculation
c WAI only defined for trees, equal to 0 for other plant types
c WAI defined as a fraction of LAIMAX (alpha(ip)*PAI, PAI '=' LAIMAX)
c WAI is given as a constant for each tree in fileibm


         fgr_tree = 0.
         if(ntree.gt.0) then
          do ip = nherb+nbush+1, npft0
           fgr_tree = fgr_tree + fgrn(ip)*frac(ip)
          end do
         endif

         fgr_herb = 0.
         if(nherb+nbush.gt.0) then
          do ip = 1, nherb+nbush 
           fgr_herb = fgr_herb + fgrn(ip)*frac(ip)
          end do        
         endif

         fgr_crop = 0.
         if(ncrop.gt.0) then
          do ip = npft0+1, npft0+ncrop
            fgr_crop = fgr_crop + fgrn(ip)*frac(ip)
          end do
         endif
	 
         fgr_past = 0.
         if(npast.gt.0) then
          do ip = npft0+ncrop+1, npft
            fgr_past = fgr_past + fgrn(ip)*frac(ip)
          end do
         endif	 

         do ip = nherb+nbush+1, npft0
            plant_wai = wai(ip)
            call fgrn_calc(plant_wai,wai_fgrn)
            woodfgrn(ip) = wai_fgrn             
         enddo

         do ip = nherb+1, nherb+nbush
            plant_wai = wai(ip)
            call fgrn_calc(plant_wai,wai_fgrn)
            woodfgrn(ip) = (frac_nat(igr)-fgr_tree)*wai_fgrn             
         enddo

         fgr_wood = 0.
c         if(ntree.gt.0) then
c          do ip = nherb+nbush+1, npft0
          do ip = nherb+1, npft0
           fgr_wood = fgr_wood + woodfgrn(ip)*frac(ip)
          end do
c         endif


c  Correct the fgreen calculation by using only frac_nat for the surface
c  covered by trees and herbs

c         fgreen = fgr_tree + (1.-fgr_tree)*fgr_herb +fgr_crop +fgr_past

         fgreen = fgr_tree + (frac_nat(igr)-fgr_tree)
     &   *fgr_herb +fgr_crop +fgr_past

c        tlai = -alog(1.-fgreen)/(0.5*clump_fac) 
         tlai = 0.
         do ip = 1, npft
          tlai = tlai + frc(ip)*plai(ip)
         end do

c  Fraction of pixel coeverd by wood for albedo calculation
         fwood =(frac_nat(igr)-fgr_tree)*fgr_wood

c   fgs: snow-free green cover  
c-----------------------------------------------------------------------
         fgs = fgreen * (1.-fsnow)
         fsn = fsnow

c=======================================================================
c   ALBEDO CALCULATION 
c=======================================================================

c   albs: soil albedo  
c-----------------------------------------------------------------------
c additional coefficient 1.7*y(2)/fsi
c for 0.1515 < soil albedo < 0.33 if colour =0.5
c instead of 0.225 < soil albedo < 0.33 
         albs=1.5*(0.10+0.1*colour
     &   +0.07*(1.-1.7*y(2)/fsi))

c   albsn: snow albedo  
c-----------------------------------------------------------------------
         if (temi.lt.0.) then
            tmfac=0.1*(temi+10.)
            if(tmfac.lt.0.001) tmfac=0.001
            tm3 = tmfac*tmfac*tmfac
            alnsw = 0.85 - 0.20 * tm3
            alnlw = 0.65 - 0.16 * tm3
            albsn = 0.5*(alnsw+alnlw)
         else
            albsn = 0.57
         endif

c   alb: average (soil+veg+snow) albedo  
c-----------------------------------------------------------------------
c         alb = fsnow*albsn
c     1         + (1.-fsnow)*(albv*fgreen+albs*(1.-fgreen))

c Correction for bare soil fraction and wood
         alb = fsnow*albsn
     1   + (1.-fsnow)*(albv*fgreen+albwd*fwood+albs*
     &   ((frac_nat(igr)+frac_crop(igr)+frac_past(igr))
     &   -fgreen-fwood))

c   albsv: average (soil+veg) albedo  
c-----------------------------------------------------------------------
         albsv = albv*fgreen+albwd*fwood+albs*
     &  ((frac_nat(igr)+frac_crop(igr)+frac_past(igr))
     &  -fgreen-fwood)

c   albsoil: average soil albedo  
c-----------------------------------------------------------------------
         albsoil = albs*
     &  ((frac_nat(igr)+frac_crop(igr)+frac_past(igr))
     &  -fgreen-fwood)

c   albvege: average vegetation albedo  
c-----------------------------------------------------------------------
         albvege = albv*fgreen+albwd*fwood


c=======================================================================
c   THERMODYNAMICAL QUANTITIES  
c   psat: pression de vapeur saturante de H2O [Pa]  
c   delta: s = d(psat)/dT  [Pa K-1]  
c   xlw: chaleur latente L d'evaporation de H2O [J kg-1]  
c=======================================================================
         call esat(tk,psat)
         if (tk.ge.temp0) then
            delta=(psat/tk)*(asat/tk-bsat)
            xlw=2.497d+6 - 2.31d+3*(tk-temp0)
         else
            delta=psat*eaice/(rgas*tk*tk)
            xlw=eaice/h2omw
         endif

c   eh2o: H2O vapour pressure (Pa)  
c   fh2o: volume mixing ratio of H2O  
c   qh2o: specific humidity (kg kg-1)  
c   airmw: air molecular weight [kg mol-1]  
c   rhoair: air density (perfect gas law) [kg m-3]  
c   rair: gas constant of wet air (J K-1 kg-1)
c-----------------------------------------------------------------------
         eh2o = hai*psat
         fh2o = eh2o/patm
         qh2o = epsi*fh2o
         airmw = (qh2o + (1.-fh2o)) * drymw
         rair = rgas/airmw
         rhoair = patm/(rair*tk)        
        
c   cpair: specific heat cp of air at constant p [J kg-1 K-1]  
c-----------------------------------------------------------------------
         cpair = cph2o*qh2o + cpdry*(1.-qh2o) 

c   gama: psychrometric constant [Pa K-1]  
c-----------------------------------------------------------------------
         gama = cpair*patm/(epsi*xlw)
         rscp_air = rair/cpair
        
c=======================================================================
c   EMISSIVITY CALCULATION 
c   emisn: emissivity of snow 
c   emiv: emissivity of vegetation 
c   emis: soil emissivity 
c   emisf: average surface emissivity 
c   emia: atmospheric emissivity 
c=======================================================================

c   snow 
c-----------------------------------------------------------------------
         emisn = 0.96

c   soil
c-----------------------------------------------------------------------
         emiwet = 0.01*(0.95*san+0.96*sil+0.97*cla)
         emidry = 0.01*(0.87*san+0.93*sil+0.95*cla)
         emis = emidry + was*(emiwet-emidry)

c   average emissivity of the surface
c-----------------------------------------------------------------------
c         emisf = fsnow*emisn
c     1         + (1.-fsnow)*(emiv*fgreen+emis*(1.-fgreen))

c Emissivity calculation corrected for bare soil fraction
c fwood not included here

         emisf = fsnow*emisn
     &         + (1.-fsnow)*(emiv*fgreen+emis*
     &  ((frac_nat(igr)+frac_crop(igr)+frac_past(igr))
     &  -fgreen))

c   average emissivity of the surface without snow (no snow)
c-----------------------------------------------------------------------
         emisfns = emiv*fgreen + emis* 
     &   ((frac_nat(igr)+frac_crop(igr)+frac_past(igr))
     &   -fgreen) 

c   atmosphere  
c   Staley & Jurica    
c         aa = 0.67-0.04*(1.013d+5-patm)/0.303d+5
c         emia = aa*((eh2o/100.)**0.08)
c   Guyot
c         emia = 0.56+0.08*sqrt(eh2o/100.)
c   Brutsaert, 1975
c         emia = 1.24*((0.01*eh2o/tk)**0.142857)
c   Crawford & Duchon, 1999 (modified Brutsaert)
c         xmon=(dn+15.2)/30.416667
c         if (ylati.lt.0.) xmon = xmon+6. 
c         aa = 1.22+0.06*dsin((xmon+2.)*pi/6.)
c         emia = aa*((0.01*eh2o/tk)**0.142857)
c   Anderson 1954
c-----------------------------------------------------------------------
         emia = 0.68+0.036*sqrt(0.01*eh2o)

         if (emia.gt.1.) emia=1.

c=======================================================================
c   AERODYNAMIC RESISTANCE 
c   rblwm, rblcv: aerodynamic resistances [s m-1] 
c                 for water (averaged over vegetation and soil) 
c                 and carbon (for each vegetation type) 
c                 respectively
c=======================================================================

         if(windi.lt.0.1)windi=0.1
         uss = usmuls*windi 
         rblws = windi/(uss*uss) + 6.2/(uss**0.67)
         xrblwm = (1.-fveg)*dlog(rblws)
c mean of log(zzra-disd)/z0
         xlog2 = (1.-fveg)/(zzlogs*zzlogs)
         do ip = 1, npft
            z0 = z0vw(ip) + fgrn(ip) * (z0vs(ip)-z0vw(ip))
            zzlog(ip) = dlog((zzra(ip)-disd(ip))/z0)
            xlog2 = xlog2 + frc(ip)/(zzlog(ip)*zzlog(ip))
         end do
         if (xlog2.gt.1.d-10) then
            zzlogm = dsqrt(1./xlog2)
         else
            zzlogm = 1.
         endif
	 
c  Determination of roughness length of the pixel
c  from drag coefficients approach (Claussen et al. (1991))
c Use of dominant plant type for reference blending height
c to be changed to use landuse type specific blending height
 
	 frcini=frc(1)
	 indicmax=1
	 do ip =1, npft
         if (frc(ip). gt. frcini) then
	     indicmax=ip
	     frcini=frc(ip)
	 else
	     indicmax=indicmax
	 endif        
	 end do

c mean pixel roughness length
	 z0tot=(zzra(indicmax)-disd(indicmax))/exp(zzlogm)
	 
c mean aerodynamic and boundary layer resistances (for water)    
         usmulm = 0.40/zzlogm
         usm = usmulm*windi
         ram = windi/(usm*usm)
         rbwm = 6.2/(usm**0.67)
         rblwm = ram + rbwm
c aerodynamic and boundary layer resistances of each plant type (for carbon) 
         do ip = 1, npft
            usmulv = 0.40/zzlog(ip)
            us = usmulv*windi
            ra = windi/(us*us)
            rbw = 6.2/(us**0.67)
            rblwv = ra + rbw
            rblcv(ip) = (ra+1.37*rbw)
         enddo



c   snowmelt (sml), rainfall (rf), and snowfall (sf) 
c  (mm day-1)
c-----------------------------------------------------------------------
        if(tmax.le.0.)then
            sml = 0.
            rf = 0.
            sf = preci
         else
            if(tmin.ge.0.)then
               sml= 4.57 * temi
               rf = preci
               sf = 0.
            else
               if((tmax-tmin).le.1.d-10)then
                  pcrain = 0.5
               else
                  pcrain = tmax / (tmax-tmin)
               endif
               sml = 0.5*pcrain * 4.57*tmax
               rf = pcrain * preci
               sf = (1.-pcrain) * preci
            endif
            smlmax = y(1) / stept
            if(sml.gt.smlmax)sml=smlmax
            if(sml.lt.0.)sml=0.
         endif

c   xlsml: Energy used for snow melt (W m-2)
c   xlice: Latent heat of ice melt (J kg-1)
c-----------------------------------------------------------------------
         xlice = 3.34d+5
         xlsml = xlice*sml/86400.

c   input fluxes (fin) 
c   (mm day-1) 
c-----------------------------------------------------------------------
         fin_w(1) = sf
         fin_w(2) = rf + sml
         exces_run = 0.

         cond_max = (12./12.) * 240.* exp(acd+bcd*rootd/fsi)             
         if (fin_w(2).gt.cond_max) then
           exces_run = fin_w(2)-cond_max
           fin_w(2) = cond_max
         endif

c=======================================================================
c   POTENTIAL EVAPOTRANSPIRATION (PENMAN)
c        pet (mm day-1) 
c=======================================================================

c   factors for Penman relationship
c-----------------------------------------------------------------------

         xleadi=(rhoair*cpair/(delta+gama))*psat*(1.-hai)/rblwm
         rnfac = delta/(delta+gama)

c  tc = cloud (bottom) temperature (K)
c-----------------------------------------------------------------------
         tc = tk-11.

         tcb = tk+5.
         tca = tk-85.
         nint=4
         ermax = 0.01
         nitmax =100
         imeth = 1
         call nonlineq(tca,tcb,nint,tc,ftc,ermax,nitmax,imeth,numc)
        
c  tatm = atmosphere (lower 1 km) temperature (K), i.e. average 
c         temperature of the atmospheric layer contributing to the 
c         downward infrared radiation during clear sky conditions 
c-----------------------------------------------------------------------

         tatm = tk
        
c   firdown = downward infrared radiation (W m-2)
c-----------------------------------------------------------------------
         firdown = emia*sigma*tatm*tatm*tatm*tatm
     1     +(1.-shi)*(1.-emia)*sigma*tc*tc*tc*tc

c   solnet : net solar radiation flux [W m-2]
c-----------------------------------------------------------------------
         solnet = solg(0) * (1.-alb)

c   loop for the calculation of Tsurf
c-----------------------------------------------------------------------
         tsurf = tk
         num1 = 10
         jbrac = 1
         numit = 0

         do jnum = 1,100
            numit = numit+1
            tsf = tsurf
c   rnet : net radiation flux Rn [W m-2] 
c-----------------------------------------------------------------------
            fird = firdown
            rnet = solnet + emisf*firdown 
     &              - emisf*sigma*tsf*tsf*tsf*tsf

c   xle : LE* from the surface (Penman) [W m-2]
c-----------------------------------------------------------------------
            xle = (rnet-grflx-xlsml)*rnfac + xleadi
c            if(xle.lt.0.)xle=0.
c   pet : potential evapotranspiration E* (Penman) [mm day-1] 
c-----------------------------------------------------------------------
            pet = 86400.*xle/xlw


c   eint : intercepted precipitation directly re-evaporated [mm day-1]
c   esnow: snow evaporation from soil-vegetation [mm day-1] 
c   esoil: evaporation from soil-vegetation [mm day-1]
c-----------------------------------------------------------------------
            if (pet.gt.0.) then
               eint=0.
               do ip=1,npft
                  if(fgrn(ip).eq.0.)then 
                     eintpl=0.
                  else
                     x=preci/pet
                     xii=(stept*pet*fgrn(ip)/(0.2*plai(ip))) 
                     x0=1./(0.84640+0.83842*xii)
                     xr=x0+1.
                     tr=0.7225-0.2529*exp(-xii/6.738)
                     xk=1./tr-1.
                     if(x.le.x0)then
                        qfrac=0.
                     else
                        if(x.le.xr)then
                           xnn=1.352
                        else
                           xnn=1.122
                        endif
                        qx=(x-x0)**xnn
                        qfrac=qx/(qx+xk)
                     endif
                     eintpl=preci*fgrn(ip)*(1.-qfrac)
                     if(eintpl.gt.pet)eintpl=pet
                  endif
                  eint=eint+eintpl*frc(ip)
               enddo
               esnow = fsnow * (pet-eint)
               esnmax = y(1) / stept - sml
               if (esnow.gt.esnmax) esnow = esnmax
               if(esnow.lt.0.)esnow=0.
               esoil = bts * (pet-eint-esnow)
               esomax = (y(2)-wpi) / stept
               if (esoil.gt.esomax) esoil = esomax
               if(esoil.lt.0.)esoil=0.
            else
               eint = 0.
               if(tmax.le.0.)then
                  esoil = 0.
                  esnow = pet
               elseif(tmin.ge.0.)then
                  esoil = pet
                  esnow = 0.
               else
                  if((tmax-tmin).le.1.d-10)then
                     pcdew = 0.5
                  else
                     pcdew = tmax / (tmax-tmin)
                  endif
                  esoil = pcdew * pet
                  esnow = (1.-pcdew) * pet
               endif
            endif


c   axle : (actual) latent heat LE from the surface [W m-2] 
c-----------------------------------------------------------------------
            axle = (eint+esnow+esoil) * xlw / 86400.
c            if(axle.lt.0.)axle=0.

c   xh : (actual) sensible heat H from the surface [W m-2] 
c-----------------------------------------------------------------------
            xh = rnet-grflx-xlsml-axle

            tsurf = tk + xh*rblwm/(rhoair*cpair)

            err = tsurf - tsf

            if (dabs(tsurf).ge.1.d+10) numit=num1
            if (dabs(err).lt.0.05) goto 340

            if (numit.eq.1) then
               tsf1=tsf
               err1=err
            elseif (numit.ge.num1) then

               if (jbrac.eq.1)then
                  if (numit.eq.num1) then
                     tsurf = tk + 1.0
                  else
                     tsf2 = tsf
                     err2 = err
                     prod = err1*err2
                     if (prod.gt.0.) then
                        if (dabs(err1).lt.dabs(err2)) then
                           tsurf = tsf1+(tsf1-tsf2)*1.7
                        else
                           tsurf = tsf2+(tsf2-tsf1)*1.7 
                           tsf1 = tsf2
                           err1 = err2
                        endif
                     else
                        tsurf = tsf1+(tsf2-tsf1)*dabs(err1)
     &                         /dabs(err1-err2)
                       jbrac = 0
                     endif  
                  endif
               else
                  prod = err*err2
                  if (prod.gt.0) then
                     tsf2 = tsf
                     err2 = err
                  else
                     tsf1 = tsf
                     err1 = err
                  endif
                  tsurf = tsf1+(tsf2-tsf1)*dabs(err1)/dabs(err1-err2)  
               endif

            endif
         enddo
         write(28,*)' CALCUL DE TS (SUB GIVEDRV)'
         write(28,*) ylongi,ylati,igr,ny0,dn,
     &     ' numit=',numit
         write(28,*)tsf1,err1
         write(28,*)tsf2,err2
         stop
340      continue
c   ts : average surface (snow+soil+vegetation) temperature (C) 
c-----------------------------------------------------------------------
         ts = tsurf - temp0

c   soil+vegetation actual evapotranspiration (soe) 
c   snow actual evaporation (sne) 
c   total actual evapotranspiration (aet) 
c   (mm day-1) 
c-----------------------------------------------------------------------
         if(preci.ne.0.)then
            rapso = rf/preci
         else
            rapso = 0.
         endif
         soe = eint * rapso + esoil
         sne = eint * (1.-rapso) + esnow
         aet = soe + sne
         svevp = esoil
	 
         
c   rtrans = ratio of plant transpiration to soil+vegetation evapotr.
         frctr = 1.-exp(-tlai)
         if (tlai.le.1.) then
           frcso = 1.-0.666*tlai
         else
           frcso = exp(-tlai)/1.1
         endif  
         rtrans = frctr/(frctr+frcso)
         if (rtrans.gt.1.) rtrans=1.
c old         if (rtrans.lt.0.6) rtrans=0.6
         if (rtrans.lt.0.) rtrans=0.


c   drun  : drainage (mm day-1) 
c   condw : soil conductivity (mm day-1) (Saxton et al, 1986)
c   thw   : soil water content (m3/m3)
c   ttl   : drainage characteristic time (day) 
c           if too short, re-evaluation of the drainage rate
c           to take the sharp variation of conductivity with
c           water content into account.
c   san, sil, cla: percent of sand, silt and clay
c-----------------------------------------------------------------------

          
c   interpolation sur le contenu en eau
c-----------------------------------------------------------------------

         k1w = 0
         if((k1w .lt. 1) .or. (k1w .ge. nwa)) k1w = 0
         if(was .lt. wa0(k1w)) k1w = 0
         k0w = k1w + 1
         do kw = k0w, nwa-1
            if(was .le. wa0(kw)) then
               k2w = kw
               goto 210
            endif
         enddo
         k2w = nwa
210      continue
         k1w =  k2w - 1

c   parametrisation interpolee pour dep. flux net
c-----------------------------------------------------------------------

         fnet = fin_w(2) - soe

         if(fnet.lt.0.)then
            if (dabs(fnet).ge.fntmax) fnet = -fntmax
            do j=0,nde+1
               ej1 = ajdr(j,k1w)
               ej2 = ajdr(j,k2w)
               ej(j) = ej1+(ej2-ej1)*(was-wa0(k1w))
     &                /(wa0(k2w)-wa0(k1w))
            enddo 
         else
            if (dabs(fnet).ge.fntmax) fnet = fntmax
            do j=0,nde+1
               ej1 = bjdr(j,k1w)
               ej2 = bjdr(j,k2w)
               ej(j) = ej1+(ej2-ej1)*(was-wa0(k1w))
     &                /(wa0(k2w)-wa0(k1w))
            enddo 
         endif
         dr = ej(0)
         do j = 1,nde+1
            fntj = 1.
            do kj = 1,j
               fntj = fntj*fnet
            enddo
            dr = dr + ej(j)*fntj
         enddo

         if (dr.lt.0.) dr=0.
         avh2o = fnet * stept + (y(2)-wpi)
         if (dr.gt.avh2o) dr=avh2o 
         drun = drn_fac * dr / stept

         t0dr = -2.
         if (tmax.le.t0dr) then
            drun = 0.
         elseif (tmax.lt.0.) then
            drun = (t0dr-tmax)*drun/t0dr
         endif


c   srun : surface runoff (mm day-1)
c-----------------------------------------------------------------------
         fnsw = fin_w(2) - soe - drun
         fnmax = (fsi-y(2)) / stept
         if (fnsw.gt.fnmax) then
            srun = exces_run + fnsw - fnmax
         else
            srun = exces_run
         endif

c   fout : output fluxes (mm day-1) 
c-----------------------------------------------------------------------
         fout_w(1) = sml + sne
         fout_w(2) = soe + drun + (srun - exces_run)


c=======================================================================
c       derivatives dy/dt [ mm day-1]
c=======================================================================

         do nr=1,nres
            drv(nr) = fin_w(nr) - fout_w(nr)
         enddo

      return
      end subroutine givedrv