c=======================================================================
c***********************************************************************
      subroutine clasparam
c***********************************************************************
c=======================================================================

c=======================================================================
c   reads or computes various age classes parameters
c=======================================================================
      IMPLICIT NONE
      
      include './com_18/parameter.common'
      include './com_18/ageclas.common'
      include './com_18/files_car.common'
      include './com_18/nspc.common'
c-----------------------------------------------
c JLP ajout� pour implicit none
c
      integer iclas,icyearplus,ip
      real*4  frac_clas_tot
c
c-----------------------------------------------

      character*50 title,pft_name(nplant)
      character*132 sdata

c=======================================================================
c     open reading file
c=======================================================================

      open(111,file=fileclaspar)
      read(111,*)title

c=======================================================================
c    loop over BAG's
c=======================================================================

      do ip = 1, npft

c=======================================================================
c    initialisation:
c       icyear_min  = minimum age of a plant for this class
c       icyear_max  = maximum age of a plant for this class
c       icyear_mean = mean age of a plant for this class
c       icyearplus  = maximum age of the last class
c       nclas       = number of age classes for this BAG
c       nlcas_max   = maximum number of age classes (6)
c       frac_clas0  = fraction of the pixel for each age class 
c                     (intital value, it will be calculated by CARAIB
c                     for following years)
c=======================================================================

       do iclas = 1, nclas_max
         icyear_min(ip,iclas)  = -1
         icyear_mean(ip,iclas) = -1
         icyear_max(ip,iclas)  = -1
       end do
       icyearplus = -1
       nclas(ip) = 1

       frac_clas0(ip,1) = 1.
       do iclas = 2, nclas_max
         frac_clas0(ip,iclas) = 0.
       end do

c=======================================================================
c    reading of data
c=======================================================================

       read(111,127) pft_name(ip),sdata
       read(sdata,*) nclas(ip),(icyear_min(ip,iclas),iclas=1,nclas_max)
     &                        ,icyearplus

c=======================================================================
c     test the data readed: 
c        icyear_min has to be greater than 0 for each of the existing
c                   classes (nclas(ip))
c        icyearplus maximum age has to be greater than the minimum age
c                   of the first class
c=======================================================================

       do iclas = 1,nclas(ip)
         if(icyear_min(ip,iclas).le.0) then
           write(61,*) 'error minimum year is nul or negative, bag:',ip,
     &                'clas:',iclas,'value:',icyear_min(ip,iclas)
           stop
         endif
       end do

       if(icyearplus.lt.icyear_min(ip,1)) icyearplus = icyear_min(ip,1)

c=======================================================================
c     calculating other data relative to age classes
c=======================================================================

       do iclas = 1, nclas(ip)-1
         icyear_max(ip,iclas) = icyear_min(ip,iclas+1) - 1
       end do
       icyear_max(ip,nclas(ip)) = icyearplus

       do iclas = 1, nclas(ip)
         icyear_mean(ip,iclas) = icyear_min(ip,iclas) 
     &       + int((icyear_max(ip,iclas)-icyear_min(ip,iclas))/2.)
       end do

c=======================================================================
c      test the calculated data:
c           icyear_mean have to be greater than 0
c           icyear_max  have to be greater than 0 and than icyear_min
c=======================================================================

       do iclas = 1, nclas(ip)

         if(icyear_max(ip,iclas).lt.icyear_min(ip,iclas)) then
          write(61,*)'error, maximum age little than minimum age, ip:',
     &     ip,'iclas:',iclas,icyear_min(ip,iclas),icyear_max(ip,iclas)
          stop 
         endif

         if(icyear_max(ip,iclas).le.0) then
          write(61,*) 'error maximum year is nul or negative, bag:',ip,
     &                'clas:',iclas,'value:',icyear_max(ip,iclas)
           stop
         endif
         if(icyear_mean(ip,iclas).le.0) then
          write(61,*) 'error mean year is nul or negative, bag:',ip,
     &                'clas:',iclas,'value:',icyear_mean(ip,iclas)
           stop
         endif
       end do

c=======================================================================
c      initial pixel faction: frac_clas0
c=======================================================================

         frac_clas_tot = 0.
         do iclas = 1, nclas(ip)
           frac_clas0(ip,iclas) =
     &        float(icyear_max(ip,iclas)-(icyear_min(ip,iclas)-1))
           frac_clas_tot = frac_clas_tot + frac_clas0(ip,iclas)
         end do
         
         do iclas = 1, nclas(ip)
          if(frac_clas_tot.le.0.) then
            frac_clas0(ip,iclas) = 0.
          else
            frac_clas0(ip,iclas) = frac_clas0(ip,iclas) / frac_clas_tot
          endif
         end do
       end do

127   format(a50,a40)

      close(111)

      return
      end subroutine clasparam