c=======================================================================
c***********************************************************************
      subroutine fraction_luc(ngt)
c***********************************************************************
c=======================================================================

c=======================================================================
c   This routine calculates carbon emission and litter production fluxes 
c   from land use change  
c=======================================================================

      implicit none

      include './com_18/parameter.common'
      include './com_18/coord.common'
      include './com_18/cte.common'
      include './com_18/ecoin.common'
      include './com_18/icyr.common'
      include './com_18/inidata.common'                              
      include './com_18/landuse.common'
      include './com_18/landuse0.common'
      include './com_18/luc.common'
      include './com_18/lucflx.common'                   
      include './com_18/nspc.common'
      include './com_18/plant_pool.common'
      include './com_18/plant_evol.common'
      include './com_18/soil_pool.common'
      
      integer ip,ipool,ngt 
      real*4 rbmax     

c=======================================================================
c   calculates (absolute and relative) changes in land use fractions 
c   with respect to the previous year
c=======================================================================

      if ((ilu.eq.1).and.(icyr_landuse.ne.0)) then
      
       dfr_nat = (frac_nat(ngt)-frac_nat0(ngt))
       if (frac_nat0(ngt).gt.1.e-10) then 
        rdfr_nat = dfr_nat/frac_nat0(ngt)
	if (rdfr_nat.lt.-1) rdfr_nat = -1
       else
        rdfr_nat = 0.
       endif
       
       dfr_crop = (frac_crop(ngt)-frac_crop0(ngt))
       if (frac_crop0(ngt).gt.1.e-10) then 
        rdfr_crop = dfr_crop/frac_crop0(ngt)
	if (rdfr_crop.lt.-1) rdfr_crop = -1
       else
        rdfr_crop = 0.
       endif
       
       dfr_past = (frac_past(ngt)-frac_past0(ngt))
       if (frac_past0(ngt).gt.1.e-10) then 
        rdfr_past = dfr_past/frac_past0(ngt)
	if (rdfr_past.lt.-1) rdfr_past = -1
       else
        rdfr_past = 0.
       endif
       
       dfr_urb = (frac_urb(ngt)-frac_urb0(ngt))
       if (frac_urb0(ngt).gt.1.e-10) then 
        rdfr_urb = dfr_urb/frac_urb0(ngt)
	if (rdfr_urb.lt.-1) rdfr_urb = -1
       else
        rdfr_urb = 0.
       endif
       
       dfr_rock = (frac_rock(ngt)-frac_rock0(ngt))
       if (frac_rock0(ngt).gt.1.e-10) then 
        rdfr_rock = dfr_rock/frac_rock0(ngt)
	if (rdfr_rock.lt.-1) rdfr_rock = -1
       else
        rdfr_rock = 0.
       endif
       
       dfr_wat = (frac_wat(ngt)-frac_wat0(ngt))
       if (frac_wat0(ngt).gt.1.e-10) then 
        rdfr_wat = dfr_wat/frac_wat0(ngt)
	if (rdfr_wat.lt.-1) rdfr_wat = -1
       else
        rdfr_wat = 0.
       endif      
                                                             
      else
      
       dfr_nat = 0.
       dfr_crop = 0.
       dfr_past = 0.
       dfr_urb = 0.
       dfr_rock = 0.
       dfr_wat = 0.      
       rdfr_nat = 0.
       rdfr_crop = 0.
       rdfr_past = 0.
       rdfr_urb = 0.
       rdfr_rock = 0.
       rdfr_wat = 0.
       
      endif
      
      
c=======================================================================      
c   Stores previous year PFT fractions into frac0 vector
c=======================================================================
      do ip = 1, npft
       frac0(ip) = yfrac_ini(ip,ngt)
      end do
            
c=======================================================================      
c   Estimation of PFT biomass per m2 of presence (g C m-2) at end of 
c   previous year (iday = nd)
c     rootsh = root:shoot ratio (from Mokani et al., Global Change Biol
c                               12, 84-96, 2006) 
c     bg_bio = belowground (root) biomass (gC m-2)
c     ag_bio = aboveground (branches and stems) biomass (gC m-2)
c=======================================================================
      do ip = 1, npft
            rbmax = (rootsh(ip)/(1.+rootsh(ip)))
     &                 *(ycar_ini(ip,1,ngt)+ycar_ini(ip,2,ngt))
            bg_bio(ip) = min(ycar_ini(ip,2,ngt),rbmax)
	    if (bg_bio(ip).lt.0.) bg_bio(ip) = 0.
	    ag_bio(ip,1) = max(ycar_ini(ip,1,ngt),0.)
	    ag_bio(ip,2) = ycar_ini(ip,2,ngt)-bg_bio(ip)	
	    
      end do

c=======================================================================      
c   Total carbon emission to the atmosphere due to land use change 
c        (gC m-2 yr-1)
c   Total carbon transfer to the litter due to land use change 
c        (gC m-2 yr-1) 
c=======================================================================

c Natural vegetation
      do ip = 1, npft0
        if (frac_nat0(ngt).gt.1.e-10) then	
          if (rdfr_nat.lt.0) then    
	   yemi_luc(ip,1) = -frac0(ip)*ag_bio(ip,1)*rdfr_nat 
	   yemi_luc(ip,2) = -frac0(ip)*ag_bio(ip,2)*rdfr_nat
	   xlit_luc(ip,1) = 0.
	   xlit_luc(ip,2) = -frac0(ip)*bg_bio(ip)*rdfr_nat
	   yfrac_ini(ip,ngt) = frac0(ip) * (1.+rdfr_nat)
	   do ipool = 1, npool
	    ylit_ini(ipool,ngt) = ylit_ini(ipool,ngt)
     &                          + xlit_luc(ip,ipool)
	   end do
	  else
	   yemi_luc(ip,1) = 0. 
	   yemi_luc(ip,2) = 0.
	   xlit_luc(ip,1) = 0.
	   xlit_luc(ip,2) = 0.
	   yfrac_ini(ip,ngt) = frac0(ip) * (1.+rdfr_nat)
	   do ipool = 1, npool
	    ycar_ini(ip,ipool,ngt)=ycar_ini(ip,ipool,ngt)/(1.+rdfr_nat)
	   end do
	   ylaimin_ini(ip,ngt)=ylaimin_ini(ip,ngt)/(1.+rdfr_nat)
	   ylaimax_ini(ip,ngt)=ylaimax_ini(ip,ngt)/(1.+rdfr_nat)
	   ybinc_ini(ip,ngt)=ybinc_ini(ip,ngt)/(1.+rdfr_nat)
	  endif	
	else
	   yemi_luc(ip,1) = 0. 
	   yemi_luc(ip,2) = 0.
	   xlit_luc(ip,1) = 0.
	   xlit_luc(ip,2) = 0.
           if (ip.le.(nherb+nbush)) then
             yfrac_ini(ip,ngt) = dfr_nat/float(nherb+nbush)
           else 
             yfrac_ini(ip,ngt) = dfr_nat/float(ntree) 
           endif   
	   do ipool = 1, npool
	    ycar_ini(ip,ipool,ngt)=0.
	   end do
	   ylaimin_ini(ip,ngt)=0.
	   ylaimax_ini(ip,ngt)=0.
	   ybinc_ini(ip,ngt)=0.	
	endif  	       
      end do     

c Crops      
      do ip = npft0+1, npft0+ncrop
        if (frac_crop0(ngt).gt.1.e-10) then      	
          if (rdfr_crop.lt.0) then    
	   yemi_luc(ip,1) = -frac0(ip)*ag_bio(ip,1)*rdfr_crop 
	   yemi_luc(ip,2) = -frac0(ip)*ag_bio(ip,2)*rdfr_crop
	   xlit_luc(ip,1) = 0.
	   xlit_luc(ip,2) = -frac0(ip)*bg_bio(ip)*rdfr_crop
	   yfrac_ini(ip,ngt) = frac0(ip) * (1.+rdfr_crop)
	   do ipool = 1, npool
	     ylit_ini(ipool,ngt) = ylit_ini(ipool,ngt)
     &                           + xlit_luc(ip,ipool)
	   end do	    
	  else
	   yemi_luc(ip,1) = 0. 
	   yemi_luc(ip,2) = 0.
	   xlit_luc(ip,1) = 0.
	   xlit_luc(ip,2) = 0.
	   yfrac_ini(ip,ngt) = frac0(ip) * (1.+rdfr_crop)
	   do ipool = 1, npool
	    ycar_ini(ip,ipool,ngt)=ycar_ini(ip,ipool,ngt)/(1.+rdfr_crop)
	   end do
	   ylaimin_ini(ip,ngt)=ylaimin_ini(ip,ngt)/(1.+rdfr_crop)
	   ylaimax_ini(ip,ngt)=ylaimax_ini(ip,ngt)/(1.+rdfr_crop)
	   ybinc_ini(ip,ngt)=ybinc_ini(ip,ngt)/(1.+rdfr_crop)
	  endif
	else
	   yemi_luc(ip,1) = 0. 
	   yemi_luc(ip,2) = 0.
	   xlit_luc(ip,1) = 0.
	   xlit_luc(ip,2) = 0. 
           yfrac_ini(ip,ngt) = dfr_nat/float(ncrop) 
	   do ipool = 1, npool
	    ycar_ini(ip,ipool,ngt)=0.
	   end do
	   ylaimin_ini(ip,ngt)=0.
	   ylaimax_ini(ip,ngt)=0.
	   ybinc_ini(ip,ngt)=0.	
	endif	  	  	       
      end do

c Pastures      
      do ip = npft0+ncrop+1, npft
        if (frac_past0(ngt).gt.1.e-10) then      	
          if (rdfr_past.lt.0) then    
	   yemi_luc(ip,1) = -frac0(ip)*ag_bio(ip,1)*rdfr_past 
	   yemi_luc(ip,2) = -frac0(ip)*ag_bio(ip,2)*rdfr_past
	   xlit_luc(ip,1) = 0.
	   xlit_luc(ip,2) = -frac0(ip)*bg_bio(ip)*rdfr_past
	   yfrac_ini(ip,ngt) = frac0(ip) * (1.+rdfr_past)
	   do ipool = 1, npool
	    ylit_ini(ipool,ngt) = ylit_ini(ipool,ngt)
     &                          + xlit_luc(ip,ipool)
	   end do	    
	  else
	   yemi_luc(ip,1) = 0. 
	   yemi_luc(ip,2) = 0.
	   xlit_luc(ip,1) = 0.
	   xlit_luc(ip,2) = 0.
	   yfrac_ini(ip,ngt) = frac0(ip) * (1.+rdfr_past)
	   do ipool = 1, npool
	    ycar_ini(ip,ipool,ngt)=ycar_ini(ip,ipool,ngt)/(1.+rdfr_past)
	   end do
	   ylaimin_ini(ip,ngt)=ylaimin_ini(ip,ngt)/(1.+rdfr_past)
	   ylaimax_ini(ip,ngt)=ylaimax_ini(ip,ngt)/(1.+rdfr_past)
	   ybinc_ini(ip,ngt)=ybinc_ini(ip,ngt)/(1.+rdfr_past)
	  endif
	else
	   yemi_luc(ip,1) = 0. 
	   yemi_luc(ip,2) = 0.
	   xlit_luc(ip,1) = 0.
	   xlit_luc(ip,2) = 0. 
           yfrac_ini(ip,ngt) = dfr_nat/float(npast) 
	   do ipool = 1, npool
	    ycar_ini(ip,ipool,ngt)=0.
	   end do
	   ylaimin_ini(ip,ngt)=0.
	   ylaimax_ini(ip,ngt)=0.
	   ybinc_ini(ip,ngt)=0.	
	endif	  	  	       
      end do      

      
      return
      end subroutine fraction_luc