c=======================================================================
c***********************************************************************
      subroutine orb_params
c***********************************************************************
c=======================================================================

c=======================================================================
c      Calculate earth's orbital parameters using Dave Threshers
c      formula which came from Berger, Andre.  1978
c      "A Simple Algorithm to Compute Long-Term Variations
c      of Daily Insolation".  Contribution 18, Institute of Astronomy and
c      Geophysics, Universite Catholique de Louvain, Louvain-la-Neuve,
c      Belgium.

c      Original Author: Erik Kluzek
c      Date:            Oct/97
c=======================================================================
      IMPLICIT NONE
      
      include './com_18/parameter.common'
      include './com_18/cstpi.common'
      include './com_18/cte.common'
      include './com_18/solpar.common'
#include "./com_18/parameter_orb.common"

CC      exc = 0.016715 !ECCEN_EARTH ! Earth's orbital eccentricity
CC      obl = 23.441 !OBLIQ_EARTH ! Earth's obliquity in degree's
CC      xlsper = 102.7 !LOPER_EARTH ! Earth's moving vernal equinox longitude
CC      real :: oblr   ! Earth's obliquity in radians
CC      real :: lambm0   ! Mean longitude of perihelion at the
                       ! vernal equinox (radians)
CC      real :: xlsperp   ! Earth's moving vernal equinox longitude
                       ! of perihelion plus pi (radians)
      real :: eccf     ! Earth-sun distance factor ( i.e. (1/r)**2 )
      integer :: nfixorb = 0 ! 1: fixed orbit parameter
      integer :: iyrad,i_AD ! Year AD to calculate orbit for
      logical, parameter :: lg_p = .true.
                       ! Flag to print-out status information or not.
                       ! (This turns off ALL status printing including)
                       ! (error messages.)       
      
c     Input Arguments
c     ---------------
CC      real :: exc        ! Earth's orbital eccentricity
CC      real :: obl        ! Earth's obliquity in degree's
CC      real :: xlsper        ! Earth's moving vernal equinox longitude

c     Output Arguments
c     ----------------
CC      real :: oblr  ! Earth's obliquity in radians
CC      real :: lambm0  ! Mean longitude of perihelion at the
c                     ! vernal equinox (radians)
CC      real :: xlsperp  ! Earth's moving vernal equinox longitude
c                     ! of perihelion plus pi (radians)

c Parameters for calculating earth's orbital characteristics
c ----------
      integer, parameter :: poblen = 47  ! number of elements in the series to calc obliquity
      integer, parameter :: pecclen = 19 ! number of elements in the series to calc eccentricity
      integer, parameter :: pmvelen = 78 ! number of elements in the series to calc vernal equinox
      real :: degrad          ! degrees to radians conversion factor
      real :: obamp(poblen)   ! amplitudes for obliquity cosine series
      real :: obrate(poblen)  ! rates for obliquity cosine series
      real :: obphas(poblen)  ! phases for obliquity cosine series
      real :: ecamp(pecclen)  ! amplitudes for eccentricity/fvelp cosine/sine series
      real :: ecrate(pecclen) ! rates for eccentricity/fvelp cosine/sine series
      real :: ecphas(pecclen) ! phases for eccentricity/fvelp cosine/sine series
      real :: mvamp(pmvelen)  ! amplitudes for mvelp sine series
      real :: mvrate(pmvelen) ! rates for mvelp sine series
      real :: mvphas(pmvelen) ! phases for mvelp sine series
      real :: yb4_1950AD      ! number of years before 1950 AD

      real, parameter :: psecdeg = 1./3600. ! arc seconds to degrees conversion

c  Cosine series data for computation of obliquity:
c  amplitude (arc seconds), rate (arc seconds/year), phase (degrees).

      data obamp /-2462.2214466D0, -857.3232075D0, -629.3231835D0,      &
     &             -414.2804924D0, -311.7632587D0,  308.9408604D0,      &
     &             -162.5533601D0, -116.1077911D0,  101.1189923D0,      &
     &              -67.6856209D0,   24.9079067D0,   22.5811241D0,      &
     &              -21.1648355D0,  -15.6549876D0,   15.3936813D0,      &
     &               14.6660938D0,  -11.7273029D0,   10.2742696D0,      &
     &                6.4914588D0,    5.8539148D0,   -5.4872205D0,      &
     &               -5.4290191D0,    5.1609570D0,    5.0786314D0,      &
     &               -4.0735782D0,    3.7227167D0,    3.3971932D0,      &
     &               -2.8347004D0,   -2.6550721D0,   -2.5717867D0,      &
     &               -2.4712188D0,    2.4625410D0,    2.2464112D0,      &
     &               -2.0755511D0,   -1.9713669D0,   -1.8813061D0,      &
     &               -1.8468785D0,    1.8186742D0,    1.7601888D0,      &
     &               -1.5428851D0,    1.4738838D0,   -1.4593669D0,      &
     &                1.4192259D0,   -1.1818980D0,    1.1756474D0,      &
     &               -1.1316126D0,    1.0896928D0/

      data obrate /31.609974D0, 32.620504D0, 24.172203D0,               &
     &             31.983787D0, 44.828336D0, 30.973257D0,               &
     &             43.668246D0, 32.246691D0, 30.599444D0,               &
     &             42.681324D0, 43.836462D0, 47.439436D0,               &
     &             63.219948D0, 64.230478D0,  1.010530D0,               &
     &              7.437771D0, 55.782177D0,  0.373813D0,               &
     &             13.218362D0, 62.583231D0, 63.593761D0,               &
     &             76.438310D0, 45.815258D0,  8.448301D0,               &
     &             56.792707D0, 49.747842D0, 12.058272D0,               &
     &             75.278220D0, 65.241008D0, 64.604291D0,               &
     &              1.647247D0,  7.811584D0, 12.207832D0,               &
     &             63.856665D0, 56.155990D0, 77.448840D0,               &
     &              6.801054D0, 62.209418D0, 20.656133D0,               &
     &             48.344406D0, 55.145460D0, 69.000539D0,               &
     &             11.071350D0, 74.291298D0, 11.047742D0,               &
     &              0.636717D0, 12.844549D0/

      data obphas /251.9025D0, 280.8325D0, 128.3057D0,                  &
     &             292.7252D0,  15.3747D0, 263.7951D0,                  &
     &             308.4258D0, 240.0099D0, 222.9725D0,                  &
     &             268.7809D0, 316.7998D0, 319.6024D0,                  &
     &             143.8050D0, 172.7351D0,  28.9300D0,                  &
     &             123.5968D0,  20.2082D0,  40.8226D0,                  &
     &             123.4722D0, 155.6977D0, 184.6277D0,                  &
     &             267.2772D0,  55.0196D0, 152.5268D0,                  &
     &              49.1382D0, 204.6609D0,  56.5233D0,                  &
     &             200.3284D0, 201.6651D0, 213.5577D0,                  &
     &              17.0374D0, 164.4194D0,  94.5422D0,                  &
     &             131.9124D0,  61.0309D0, 296.2073D0,                  &
     &             135.4894D0, 114.8750D0, 247.0691D0,                  &
     &             256.6114D0,  32.1008D0, 143.6804D0,                  &
     &              16.8784D0, 160.6835D0,  27.5932D0,                  &
     &             348.1074D0,  82.6496D0/

c  Cosine/sine series data for computation of eccentricity and
c  fixed vernal equinox longitude of perihelion (fvelp):
c  amplitude, rate (arc seconds/year), phase (degrees).

      data ecamp /0.01860798D0,  0.01627522D0, -0.01300660D0,           &
     &            0.00988829D0, -0.00336700D0,  0.00333077D0,           &
     &           -0.00235400D0,  0.00140015D0,  0.00100700D0,           &
     &            0.00085700D0,  0.00064990D0,  0.00059900D0,           &
     &            0.00037800D0, -0.00033700D0,  0.00027600D0,           &
     &            0.00018200D0, -0.00017400D0, -0.00012400D0,           &
     &            0.00001250D0/

      data ecrate /4.2072050D0,  7.3460910D0, 17.8572630D0,             &
     &            17.2205460D0, 16.8467330D0,  5.1990790D0,             &
     &            18.2310760D0, 26.2167580D0,  6.3591690D0,             &
     &            16.2100160D0,  3.0651810D0, 16.5838290D0,             &
     &            18.4939800D0,  6.1909530D0, 18.8677930D0,             &
     &            17.4255670D0,  6.1860010D0, 18.4174410D0,             &
     &             0.6678630D0/

      data ecphas /28.620089D0, 193.788772D0, 308.307024D0,             &
     &            320.199637D0, 279.376984D0,  87.195000D0,             &
     &            349.129677D0, 128.443387D0, 154.143880D0,             &
     &            291.269597D0, 114.860583D0, 332.092251D0,             &
     &            296.414411D0, 145.769910D0, 337.237063D0,             &
     &            152.092288D0, 126.839891D0, 210.667199D0,             &
     &             72.108838D0/

c  Sine series data for computation of moving vernal equinox
c  longitude of perihelion:
c  amplitude (arc seconds), rate (arc seconds/year), phase (degrees).

      data mvamp /7391.0225890D0, 2555.1526947D0, 2022.7629188D0,       &
     &           -1973.6517951D0, 1240.2321818D0,  953.8679112D0,       &
     &            -931.7537108D0,  872.3795383D0,  606.3544732D0,       &
     &            -496.0274038D0,  456.9608039D0,  346.9462320D0,       &
     &            -305.8412902D0,  249.6173246D0, -199.1027200D0,       &
     &             191.0560889D0, -175.2936572D0,  165.9068833D0,       &
     &             161.1285917D0,  139.7878093D0, -133.5228399D0,       &
     &             117.0673811D0,  104.6907281D0,   95.3227476D0,       &
     &              86.7824524D0,   86.0857729D0,   70.5893698D0,       &
     &             -69.9719343D0,  -62.5817473D0,   61.5450059D0,       &
     &             -57.9364011D0,   57.1899832D0,  -57.0236109D0,       &
     &             -54.2119253D0,   53.2834147D0,   52.1223575D0,       &
     &             -49.0059908D0,  -48.3118757D0,  -45.4191685D0,       &
     &             -42.2357920D0,  -34.7971099D0,   34.4623613D0,       &
     &             -33.8356643D0,   33.6689362D0,  -31.2521586D0,       &
     &             -30.8798701D0,   28.4640769D0,  -27.1960802D0,       &
     &              27.0860736D0,  -26.3437456D0,   24.7253740D0,       &
     &              24.6732126D0,   24.4272733D0,   24.0127327D0,       &
     &              21.7150294D0,  -21.5375347D0,   18.1148363D0,       &
     &             -16.9603104D0,  -16.1765215D0,   15.5567653D0,       &
     &              15.4846529D0,   15.2150632D0,   14.5047426D0,       &
     &             -14.3873316D0,   13.1351419D0,   12.8776311D0,       &
     &              11.9867234D0,   11.9385578D0,   11.7030822D0,       &
     &              11.6018181D0,  -11.2617293D0,  -10.4664199D0,       &
     &              10.4333970D0,  -10.2377466D0,   10.1934446D0,       &
     &             -10.1280191D0,   10.0289441D0,  -10.0034259D0/

      data mvrate /31.609974D0, 32.620504D0, 24.172203D0,               &
     &              0.636717D0, 31.983787D0,  3.138886D0,               &
     &             30.973257D0, 44.828336D0,  0.991874D0,               &
     &              0.373813D0, 43.668246D0, 32.246691D0,               &
     &             30.599444D0,  2.147012D0, 10.511172D0,               &
     &             42.681324D0, 13.650058D0,  0.986922D0,               &
     &              9.874455D0, 13.013341D0,  0.262904D0,               &
     &              0.004952D0,  1.142024D0, 63.219948D0,               &
     &              0.205021D0,  2.151964D0, 64.230478D0,               &
     &             43.836462D0, 47.439436D0,  1.384343D0,               &
     &              7.437771D0, 18.829299D0,  9.500642D0,               &
     &              0.431696D0,  1.160090D0, 55.782177D0,               &
     &             12.639528D0,  1.155138D0,  0.168216D0,               &
     &              1.647247D0, 10.884985D0,  5.610937D0,               &
     &             12.658184D0,  1.010530D0,  1.983748D0,               &
     &             14.023871D0,  0.560178D0,  1.273434D0,               &
     &             12.021467D0, 62.583231D0, 63.593761D0,               &
     &             76.438310D0,  4.280910D0, 13.218362D0,               &
     &             17.818769D0,  8.359495D0, 56.792707D0,               &
     &              8.448301D0,  1.978796D0,  8.863925D0,               &
     &              0.186365D0,  8.996212D0,  6.771027D0,               &
     &             45.815258D0, 12.002811D0, 75.278220D0,               &
     &             65.241008D0, 18.870667D0, 22.009553D0,               &
     &             64.604291D0, 11.498094D0,  0.578834D0,               &
     &              9.237738D0, 49.747842D0,  2.147012D0,               &
     &              1.196895D0,  2.133898D0,  0.173168D0/

      data mvphas /251.9025D0, 280.8325D0, 128.3057D0,                  &
     &             348.1074D0, 292.7252D0, 165.1686D0,                  &
     &             263.7951D0,  15.3747D0,  58.5749D0,                  &
     &              40.8226D0, 308.4258D0, 240.0099D0,                  &
     &             222.9725D0, 106.5937D0, 114.5182D0,                  &
     &             268.7809D0, 279.6869D0,  39.6448D0,                  &
     &             126.4108D0, 291.5795D0, 307.2848D0,                  &
     &              18.9300D0, 273.7596D0, 143.8050D0,                  &
     &             191.8927D0, 125.5237D0, 172.7351D0,                  &
     &             316.7998D0, 319.6024D0,  69.7526D0,                  &
     &             123.5968D0, 217.6432D0,  85.5882D0,                  &
     &             156.2147D0,  66.9489D0,  20.2082D0,                  &
     &             250.7568D0,  48.0188D0,   8.3739D0,                  &
     &              17.0374D0, 155.3409D0,  94.1709D0,                  &
     &             221.1120D0,  28.9300D0, 117.1498D0,                  &
     &             320.5095D0, 262.3602D0, 336.2148D0,                  &
     &             233.0046D0, 155.6977D0, 184.6277D0,                  &
     &             267.2772D0,  78.9281D0, 123.4722D0,                  &
     &             188.7132D0, 180.1364D0,  49.1382D0,                  &
     &             152.5268D0,  98.2198D0,  97.4808D0,                  &
     &             221.5376D0, 168.2438D0, 161.1199D0,                  &
     &              55.0196D0, 262.6495D0, 200.3284D0,                  &
     &             201.6651D0, 294.6547D0,  99.8233D0,                  &
     &             213.5577D0, 154.1631D0, 232.7153D0,                  &
     &             138.3034D0, 204.6609D0, 106.5938D0,                  &
     &             250.4676D0, 332.3345D0,  27.3039D0/

c     Local variables
c     ---------------
      integer i        ! Index for series summations
      real :: obsum    ! Obliquity series summation
      real :: cossum   ! Cosine series summation for eccentricity/fvelp
      real :: sinsum   ! Sine series summation for eccentricity/fvelp
      real :: fvelp    ! Fixed vernal equinox longitude of perihelion
      real :: mvsum    ! mvelp series summation
      real :: beta     ! Intermediate argument for lambm0
      real :: years    ! Years to time of interest (negative = past;
c                      ! positive = future)
      real :: exc2   ! eccentricity squared
      real :: exc3   ! eccentricity cubed
CC      real :: pi       ! pi 

c radinp and algorithms below will need a degrees to radians conversion
c factor.

CC      pi     =  4.*atan(1.)
      degrad = pi/180.

c Check for flag to use input orbit parameters
        i_AD = myear  !!!!!! REMPLACER PAR nyear2 si Holocene
        if(imig.eq.1) i_AD = 1950 - nyear2

      if ( i_AD .eq. ORB_NOT_YEAR_BASED ) then

c Check input obliq, eccen, and mvelp to ensure reasonable

         if( obl .eq. ORB_UNDEF_REAL )then
          if ( lg_p ) then
            write(*,*)'(orb_params) Have to specify orbital parameters:'
            write(*,*) 'Either set: '                                   &
     &                ,'i_AD, OR [obl, exc, and xlsper]:'
            write(*,*)'i_AD is the year to simulate the orbit for ' 
     &                ,'(ie. 1950): '
            write(*,*)'obl, exc, xlsper specify the orbit directly:'
            write(*,*)'The AMIP II settings (for a 1995 orbit) are: '
            write(*,*)' obl = 23.4441'
            write(*,*)' exc = 0.016715'
            write(*,*)' xlsper = 102.7'
          end if
          stop 999
         else if ( lg_p ) then
           write(*,*)'(orb_params) Use input orbital parameters: '
         end if
         if( (obl.lt.ORB_OBLIQ_MIN).or.(obl.gt.ORB_OBLIQ_MAX) ) then
          if ( lg_p ) then
             write(*,*) '(orb_params): Input obliquity unreasonable: '  &
     &                  ,obl
          end if
          stop 999
         end if
         if( (exc.lt.ORB_ECCEN_MIN).or.(exc.gt.ORB_ECCEN_MAX) ) then
          if ( lg_p ) then
            write(*,*) '(orb_params): Input eccentricity unreasonable: '&
     &                 ,exc
          end if
          stop 999
         end if
         if( (xlsper.lt.ORB_MVELP_MIN).or.
     &             (xlsper.gt.ORB_MVELP_MAX) ) then
          if ( lg_p ) then
         write(*,*)'(orb_params): Input mvelp unreasonable: ',xlsper
          end if
          stop 999
         end if
        exc2 = exc*exc
        exc3 = exc2*exc
      else

c Otherwise calculate based on years before present

        yb4_1950AD = 1950.0 - float(i_AD)
        if ( abs(yb4_1950AD) .gt. 1000000.0 )then
          if ( lg_p ) then
            write(*,*)'(orb_params) orbit only valid for years+-1000000'
            write(*,*)'(orb_params) Relative to 1950 AD'
            write(*,*)'(orb_params) # of years before 1950: ',yb4_1950AD
            write(*,*)'(orb_params) Year to simulate was  : ',i_AD
          end if
          stop 999
        end if


c The following calculates the earth's obliquity, orbital eccentricity
c (and various powers of it) and vernal equinox mean longitude of
c perihelion for years in the past (future = negative of years past),
c using constants (see parameter section) given in the program of:

c Berger, Andre.  1978  A Simple Algorithm to Compute Long-Term Variations
c of Daily Insolation.  Contribution 18, Institute of Astronomy and
c Geophysics, Universite Catholique de Louvain, Louvain-la-Neuve, Belgium.

c and formulas given in the paper (where less precise constants are also
c given):

c Berger, Andre.  1978.  Long-Term Variations of Daily Insolation and
c Quaternary Climatic Changes.  J. of the Atmo. Sci. 35:2362-2367

c The algorithm is valid only to 1,000,000 years past or hence.
c For a solution valid to 5-10 million years past see the above author.
c Algorithm below is better for years closer to present than is the
c 5-10 million year solution.

c Years to time of interest must be negative of years before present
c (1950) in formulas that follow.

        years = - yb4_1950AD

c In the summations below, cosine or sine arguments, which end up in
c degrees, must be converted to radians via multiplication by degrad.

c Summation of cosine series for obliquity (epsilon in Berger 1978) in
c degrees. Convert the amplitudes and rates, which are in arc seconds, into
c degrees via multiplication by psecdeg (arc seconds to degrees conversion
c factor).  For obliq, first term is Berger 1978's epsilon star; second
c term is series summation in degrees.
c
        obsum = 0.0
        do i = 1, poblen
          obsum = obsum +                                               &
     &           obamp(i)*psecdeg*cos((obrate(i)*psecdeg*years +        &
     &                                obphas(i))*degrad)
        end do
        obl = 23.320556 + obsum

c Summation of cosine and sine series for computation of eccentricity
c (eccen; e in Berger 1978) and fixed vernal equinox longitude of perihelion
c (fvelp; pi in Berger 1978), which is used for computation of moving vernal
c equinox longitude of perihelion.  Convert the rates, which are in arc
c seconds, into degrees via multiplication by psecdeg.

        cossum = 0.0
        do i = 1, pecclen
          cossum = cossum +                                             &
     &            ecamp(i)*cos((ecrate(i)*psecdeg*years +               &
     &                          ecphas(i))*degrad)
        end do

        sinsum = 0.0
        do i = 1, pecclen
          sinsum = sinsum +                                             &
     &            ecamp(i)*sin((ecrate(i)*psecdeg*years +               &
     &                          ecphas(i))*degrad)
        end do

c Use summations to calculate eccentricity

        exc2 = cossum*cossum + sinsum*sinsum
        exc = sqrt(exc2)
        exc3 = exc2*exc

c A series of cases for fvelp, which is in radians.

        if (abs(cossum) .le. 1.0E-8) then
          if (sinsum .eq. 0.0) then
            fvelp = 0.0
          else if (sinsum .lt. 0.0) then
            fvelp = 1.5*pi
          else if (sinsum .gt. 0.0) then
            fvelp = .5*pi
          endif
        else if (cossum .lt. 0.0) then
          fvelp = atan(sinsum/cossum) + pi
        else if (cossum .gt. 0.0) then
          if (sinsum .lt. 0.0) then
            fvelp = atan(sinsum/cossum) + 2.0*pi
          else
            fvelp = atan(sinsum/cossum)
          endif
        endif

c Summation of sine series for computation of moving vernal equinox longitude
c of perihelion (mvelp; omega bar in Berger 1978) in degrees.  For mvelp,
c first term is fvelp in degrees; second term is Berger 1978's psi bar times
c years and in degrees; third term is Berger 1978's zeta; fourth term is
c series summation in degrees.  Convert the amplitudes and rates, which are
c in arc seconds, into degrees via multiplication by psecdeg.  Series summation
c plus second and third terms constitute Berger 1978's psi, which is the
c general precession.

        mvsum = 0.0
        do i = 1, pmvelen
          mvsum = mvsum +                                               &
     &           mvamp(i)*psecdeg*sin((mvrate(i)*psecdeg*years +        &
     &                                mvphas(i))*degrad)
        end do
        xlsper = fvelp/degrad + 50.439273*psecdeg*years + 3.392506       &
     &  + mvsum

c Cases to make sure mvelp is between 0 and 360.

        do while (xlsper .lt. 0.0)
          xlsper = xlsper + 360.0
        end do
        do while (xlsper .ge. 360.0)
          xlsper = xlsper - 360.0
        end do
      end if  ! end of test on whether to calculate or use input orbital params

c Orbit needs the obliquity in radians

      oblr = obl*degrad

c 180 degrees must be added to mvelp since observations are made from the
c earth and the sun is considered (wrongly for the algorithm) to go around
c the earth. For a more graphic explanation see Appendix B in:

c A. Berger, M. Loutre and C. Tricot. 1993.  Insolation and Earth's Orbital
c Periods.  J. of Geophysical Research 98:10,341-10,362.

c Additionally, orbit will need this value in radians. So mvelp becomes
c mvelpp (mvelp plus pi)

      xlsperp = (xlsper + 180.)*degrad

c Set up an argument used several times in lambm0 calculation ahead.

      beta = sqrt(1. - exc2)

c The mean longitude at the vernal equinox (lambda m nought in Berger
c 1978; in radians) is calculated from the following formula given in
c Berger 1978.  At the vernal equinox the true longitude (lambda in Berger
c 1978) is 0.

      lambm0 = 2.*((.5*exc + .125*exc3)*(1. + beta)*sin(xlsperp)     
     &            - .25*exc2*(.5 + beta)*sin(2.*xlsperp)               
     &            + .125*exc3*(1./3. + beta)*sin(3.*xlsperp))

      if ( lg_p ) then
c        write(*,*) exc,obl,xlsper
CC        write(*,'(/," ****************************************")')
CC        write(*,'(" *     Computed Orbital Parameters      *")')
CC        write(*,'(" ****************************************")')
CC        write(*,'(" * Year AD           = ",i16  ," *")') i_AD
CC        write(*,'(" * Eccentricity      = ",f16.6," *")') exc
CC        write(*,'(" * Obliquity (deg)   = ",f16.6," *")') obl
CC        write(*,'(" * Obliquity (rad)   = ",f16.6," *")') oblr
CC        write(*,'(" * Long of perh(deg) = ",f16.6," *")') xlsper
CC        write(*,'(" * Long of perh(rad) = ",f16.6," *")') xlsperp
CC        write(*,'(" * Long at v.e.(rad) = ",f16.6," *")') lambm0
CC        write(*,'(" ****************************************")')
      end if
      
      xlsper  =    xlsperp
      obl     =     oblr

      exc4    = exc * exc
      exc5    = exc4 * exc
      exc6    = 2. * exc
      exc7    = 2.5 * exc4      

      return
      end subroutine orb_params