c=======================================================================
c***********************************************************************
      subroutine solar
c***********************************************************************
c=======================================================================

c=======================================================================
c   calculates the solar irradiance at the earth surface
c
c   inputs:   idn   = day number (dimensionless);
c             ylati   = latitude of the grid point studied (degrees)
c             shi   = relative sunshine hours (dimensionless);
c             nh    = number of hours in one day.
c
c   outputs:  solday = hourly value of the surface solar irradiance
c                      for the grid point studied (w m-2);
c             ftrday = hourly value of the atmospheric transmit-
c                      tance for the grid point studied
c                      (dimensionless);
c             xmuday = cosine of the solar zenithal angle , one 
c                      value at each hour (dimensionless) +  mean
c                      values (ih =0.).
c=======================================================================

C -- JLP      implicit double precision (a-h,o-z)
      IMPLICIT NONE      

      include './com_18/parameter.common'
      include './com_18/climin.common'      
      include './com_18/coord.common'
      include './com_18/cstpi.common'
      include './com_18/cte.common'
      include './com_18/solpar.common'
      include './com_18/varday.common'
c-----------------------------------------------
c JLP ajout� pour implicit none
c
      integer i,idn
      real*8  cdel,ch0,cte,cxlt,cz,cz0,dn,h,h0,heure,qfac,rm,sdel,slg
     &      ,sth,sxlt,th,theta,xls
c
c-----------------------------------------------

      qfac = float(nh) / 24.

      do idn = 1,nd

         dn = float(idn-1)

c=======================================================================
c   calculates necessary angles:
c   sdel  = sinus of solar declination;
c   h0    = solar hour angle at sunset
c=======================================================================

         slg   = pi365 * (dn - 79.092)
         if(slg .lt. 0.) slg = 2. * pi + slg
         th    = slg - xlsper
         sth   = dsin(th)
         xls   = slg + 2.*sth*exc + 2.5*sth*dcos(th)*exc*exc
     &        + (3.*sth - 13.*sth*sth*sth/3.) * exc * exc * exc
         theta = xls - xlsper
         rm    = (1. - exc*exc) / (1. + exc*dcos(theta))
         sdel  = sin(obl) * sin(xls)
         cdel  = dsqrt(1.-sdel*sdel)
         cte   = sunea / (rm * rm)

         sxlt  = sin(ylati * pi / 180.)
         cxlt  = cos(ylati * pi / 180.)
         if(cxlt .le. 1.d-20) cxlt = 1.d-20

         ch0   = -sxlt * sdel / (cxlt * cdel)
         if(ch0 .ge. 1.) then
           h0 = 0.
         else
           if(ch0 .le. -1) then
             h0 = pi
           else
             h0 = acos(ch0)
           endif
         endif

c=======================================================================
c   calculates  the mean cosine of the solar zenith angle.
c=======================================================================

         cz0 = (h0 * sxlt * sdel + cxlt * cdel * dsin(h0)) / pi
         xmuday(idn,0)  = 0.
         if(h0 .ne. 0.) then
           xmuday(idn,0) = cz0 * pi / h0
         endif
	    
         if (isol.eq.1) then
           if (h0 .ne. 0) then 
             sunhour(idn)=(fsol(idn)/(cte*cz0)-ftrmin)/(ftrmax-ftrmin)
             if (sunhour(idn).le.0.) sunhour(idn)=0.
             if (sunhour(idn).ge.1.) sunhour(idn)=1.
           else
             sunhour(idn)=0.5
          endif
        endif
	 
        ftrday(idn,0) = ftrmin + (ftrmax-ftrmin) * sunhour(idn)
        solday(idn,0) = cte*cz0*ftrday(idn,0)
	 
	     

c=======================================================================
c   loops over the hours
c=======================================================================

         do i = 1, nh2

           heure = (float(i) - 0.5) / qfac
           h = pi * (heure - 12.)/12.

           cz = sxlt*sdel+cxlt*cdel*dcos(h)
           ftrday(idn,i) = ftrmin + (ftrmax-ftrmin) * sunhour(idn)

           if(dabs(h) .ge. h0) then
              xmuday(idn,i)  = 0.
              solday(idn,i) = 0.
           else
              xmuday(idn,i)  = cz
              solday(idn,i) = cte*cz*ftrday(idn,i)
           endif
	       
         enddo
      enddo

      return
      end subroutine solar