!   +------------------------------------------------------------------+
!   |  Subroutine Make_clim                      12/04/2024   MAR      |
!   +------------------------------------------------------------------+
!   |                                                                  |
!   | This routine  purpose us to create the CARIB clim files from MAR |
!   | one. It create the clim file that are read by CARAIB.            |
!   |                                                                  |
!   | Input : mar_lon(mx, my) : Input MAR points position x(i,j)       |
!   | ^^^^^^^ mar_lat(mx, my) :   "     "    "       "     y(i,j)      |
!   |         varname : the name of the varaible that is written       |
!   |         var(mx, my)    : the clim var                            |
!   |         MARyear : The year for witch the data is written         |
!   |         daynbr  : the day number of the year                     |
!   | Output: climdata.dat                                             |
!   | ^^^^^^^                                                          |
!   |                                                                  |
!   +------------------------------------------------------------------+

      !SUBROUTINE
      program mar2car!(mar_lon,mar_lat,FAO_nbr,clay,sand,silt,sh,avg_col,fland)
      
      use mardim
      IMPLICIT NONE

! +---General and local variables
! +   ---------------------------

      INTEGER  i,j,iostat, MARyear, daynbr

      REAL mar_lon(mx,my), mar_lat(mx,my), var(mx,my), to_write(366), to_read(368)
      
      character(len=10) :: varname = 'tem'
      character(len=100) :: filename
      character(len=100) :: tmp_file = '../CARAIB_couplage/clim/Belgium/tmp.dat'
      character(len=4) :: yyyy


! +   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

! +---mock fill
! +   -----------------
      
      MARyear = 1901
      

      filename = '../CARAIB_couplage/clim/Belgium/'

      write(yyyy, '(I4)') MARyear
      
      filename = trim(filename) // trim(varname) // trim(yyyy) // ".dat" 
      
      

      do daynbr = 1,50
            print*, "day number ,", daynbr
            inquire(file=filename, exist=iostat)
      if (iostat == 0) then
            ! File does not exist, create it
            open(unit=81, file=filename, status='unknown', action='write', iostat=iostat)
            if (iostat /= 0) then
                print *, 'Error creating file ', trim(filename)
                stop
            else
                  print *, "creating the file"
                  DO i=1,cx 
                        DO j=1,cy
                              mar_lon(i,j) = 5.64853  ! just to test
                              mar_lat(i,j) = 50.93642

                              var(i,j) = i

                              to_write(daynbr) = var(i,j)

                              write(81,123) ,mar_lon(i,j),mar_lat(i,j), to_write

                  123   format(f8.3,1x,f8.3,366(1x,f6.2)) 
 
                        enddo
                        enddo
                        close(81)
                        close(10081)
            endif
      else
            print *, 'File ', trim(filename), ' already exists.'


            open(unit=81, file=filename, status='old')
           
            open(unit=10081, file=tmp_file, status='unknown')
            
            DO i=1,cx
                  DO j=1,cy
                        var(i,j) = i
                        mar_lon(i,j) = 5.64853  ! just to test
                        mar_lat(i,j) = 50.93642
                        !print *,to_read
                        read(81,  *)  to_read
                        
                        to_write = to_read(3:368)
                        to_write(daynbr) = var(i,j)
                        write(10081,123) ,mar_lon(i,j),mar_lat(i,j), to_write

            enddo
            enddo
            close(81)
            close(10081)
            call system('mv ' // trim(adjustl(tmp_file)) // ' ' // trim(adjustl(filename)))
      endif
enddo
      end program
      !end subroutine